(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    183443,       4222]
NotebookOptionsPosition[     78260,       2105]
NotebookOutlinePosition[    174259,       4064]
CellTagsIndexPosition[    173559,       4034]
WindowTitle->Depuraci\363n de c\363digo: Una introducci\363n elemental a \
Wolfram Language
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Depuraci\[OAcute]n de c\[OAcute]digo", "SectionInline"],
  $Line = 0; Null]], "SectionDoubleDigit",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CounterAssignments->{{"Section", 46}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:291"],

Cell["\<\
Hasta los programadores m\[AAcute]s experimentados se ven obligados a pasar \
por el proceso de depuraci\[OAcute]n de sus c\[OAcute]digos; esto es algo \
inevitable en la programaci\[OAcute]n. Sin embargo, si se siguen unos cuantos \
principios b\[AAcute]sicos, la depuraci\[OAcute]n puede ser particularmente f\
\[AAcute]cil en el caso de Wolfram Language.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:1"],

Cell["\<\
El primero, y m\[AAcute]s importante, de tales principios es que hay que \
probar cada porci\[OAcute]n del c\[OAcute]digo que se escribe. Y esto se \
puede ir haciendo de manera casi instant\[AAcute]nea, debido a que Wolfram \
Language es interactivo, a la vez que simb\[OAcute]lico. Esto significa que \
aunque se hagan modificaciones muy peque\[NTilde]as, el c\[OAcute]digo se \
puede ejecutar de nuevo para ver si los ejemplos de prueba siguen \
funcionando. De no ser as\[IAcute], simplemente se arregla esa \
porci\[OAcute]n del c\[OAcute]digo y se sigue adelante.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:2"],

Cell["\<\
En ocasiones, Wolfram Language puede detectar alg\[UAcute]n posible error \
inmediatamente despu\[EAcute]s de que se ingresa algo y, en ese caso, lo se\
\[NTilde]alar\[AAcute] marc\[AAcute]ndolo en rojo. \
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell["\<\
Una porci\[OAcute]n de c\[OAcute]digo con problemas, que se se\[NTilde]alan \
en color rojo:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:3"],

Cell[BoxData[
 RowBox[{"WordCloud", "[", 
  RowBox[{
   RowBox[{"Nest", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"Length", "[", "\[ThinSpace]", "]"}], "+", 
         RowBox[{"Reverse", "[", 
          RowBox[{"#", ",", "1", ",", "2"}], "]"}]}]}], "]"}], "&"}], ",", 
     RowBox[{"{", "0", "}"}], ",", "m"}], "]"}], ",", 
   RowBox[{"Spacings", "\[Rule]", "0"}]}], "]"}]], "Input",
 Deletable->False,
 ShowSyntaxStyles->True],

Cell["\<\
Despu\[EAcute]s de ejecutar alguna porci\[OAcute]n de c\[OAcute]digo, Wolfram \
Language puede indicar si algo est\[AAcute] obviamente mal, en cuyo caso \
mostrar\[AAcute] en la pantalla un mensaje a tal efecto. Por ejemplo, el c\
\[OAcute]digo a continuaci\[OAcute]n termina solicitando el primer elemento \
de una lista de longitud 0.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:4"],

Cell[TextData[{
 "Algo est\[AAcute] obviamente mal si se aplica ",
 ButtonBox["First",
  BaseStyle->"Link"],
 " a la lista vac\[IAcute]a ",
 Cell[BoxData[
  RowBox[{"{", "}"}]], "InlineCode"],
 " generada por ",
 ButtonBox["Cases",
  BaseStyle->"Link"],
 ": "
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"First", "[", 
  RowBox[{"Cases", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", "777"}], "]"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[1]:="],

Cell[BoxData[
 TemplateBox[{
  "First","nofirst",
   "\"\\!\\(\\*RowBox[{\\\"{\\\", \\\"}\\\"}]\\) has zero length and no first \
element.\"",2,9,17,19749701560738562035,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData[
 RowBox[{"First", "[", 
  RowBox[{"{", "}"}], "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[1]="]
}, Open  ]],

Cell["\<\
A veces Wolfram Language se topa con algo que no sabe c\[OAcute]mo manejar, \
sin estar seguro de que haya alg\[UAcute]n problema. En tales casos, \
simplemente deja la entrada tal cual y la regresa en una forma \
simb\[OAcute]lica que m\[AAcute]s tarde podr\[IAcute]a tener alg\[UAcute]n \
valor definitivo.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:6"],

Cell[TextData[{
 "Si no se han dado valores para ",
 Cell[BoxData["a"], "InlineCode"],
 ", ",
 Cell[BoxData["b"], "InlineCode"],
 " y ",
 Cell[BoxData["c"], "InlineCode"],
 ", Wolfram Language simplemente regresa la entrada sin cambios:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[2]:="],

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
Si se quiere generar una gr\[AAcute]fica con partes simb\[OAcute]licas que no \
se pueden procesar, se produce una caja en color rosa:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Circle", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
    RowBox[{"Disk", "[", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], "]"}]}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[3]:="],

Cell[BoxData[
 GraphicsBox[{CircleBox[{0, 0}], DiskBox[{$CellContext`a, $CellContext`b}]},
  ImageSize->{38.72265625, Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[{
 "Cuando se est\[AAcute]n construyendo funciones, es com\[UAcute]n que haya \
fragmentos del c\[OAcute]digo que se desea probar antes de haber completado \
la funci\[OAcute]n. Esto se puede hacer asignando valores a variables con ",
 ButtonBox["With, ",
  BaseStyle->"Link"],
 "que trabaja de forma parecida a ",
 ButtonBox["Module",
  BaseStyle->"Link"],
 ", salvo que no permite reasignar los valores."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{"LastCellOfAPage", "i:8"}],

Cell[TextData[{
 "Use ",
 ButtonBox["With",
  BaseStyle->"Link"],
 " para asignar ",
 Cell[BoxData[
  RowBox[{"m", 
   ButtonBox["=",
    BaseStyle->"Link",
    ButtonData->"Set"], "4"}]], "InlineCode"],
 " temporalmente, para probar un fragmento de c\[OAcute]digo:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{"p:292", "i:9"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"m", "=", "4"}], "}"}], ",", 
   RowBox[{"Nest", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"Length", "[", "#", "]"}], "+", 
         RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
     RowBox[{"{", "0", "}"}], ",", "m"}], "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "1", ",", "3", ",", "2", ",", "6", ",", "7", ",", "5", ",", "4", 
   ",", "12", ",", "13", ",", "15", ",", "14", ",", "10", ",", "11", ",", "9",
    ",", "8"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
Si en alg\[UAcute]n caso la depuraci\[OAcute]n parece tomar demasiado tiempo, \
esto se debe generalmente a que uno se ha equivocado al juzgar qu\[EAcute] es \
lo que hace el c\[OAcute]digo. En mi experiencia, lo mejor para solventar \
esto es simplemente analizar de manera sistem\[AAcute]tica el comportamiento \
del c\[OAcute]digo, haciendo tablas con los resultados, generando \
visualizaciones, probando las afirmaciones, y todo eso. \
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:10"],

Cell["\<\
Producir algunas gr\[AAcute]ficas para ver lo que est\[AAcute] haciendo el c\
\[OAcute]digo:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "/@", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Nest", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{"#", ",", 
         RowBox[{
          RowBox[{"Length", "[", "#", "]"}], "+", 
          RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
      RowBox[{"{", "0", "}"}], ",", "m"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "6"}], "}"}]}], "]"}]}]], "Input",
 Deletable->False,
 CellLabel->"In[5]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.019444444444444445`], AbsoluteThickness[1.6], 
       LineBox[{{1., 0.}, {2., 1.}}]}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 2.}, {0, 1.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.019444444444444445`], AbsoluteThickness[1.6], 
       LineBox[{{1., 0.}, {2., 1.}, {3., 3.}, {4., 2.}}]}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 4.}, {0, 3.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.019444444444444445`], AbsoluteThickness[1.6], 
       LineBox[{{1., 0.}, {2., 1.}, {3., 3.}, {4., 2.}, {5., 6.}, {6., 7.}, {
        7., 5.}, {8., 4.}}]}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 8.}, {0, 7.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.019444444444444445`], AbsoluteThickness[1.6], 
       LineBox[{{1., 0.}, {2., 1.}, {3., 3.}, {4., 2.}, {5., 6.}, {6., 7.}, {
        7., 5.}, {8., 4.}, {9., 12.}, {10., 13.}, {11., 15.}, {12., 14.}, {
        13., 10.}, {14., 11.}, {15., 9.}, {16., 8.}}]}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 16.}, {0, 15.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.019444444444444445`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJx1z7sKwkAUhOHFyjKFhYVFIkFEJMT73Zxn8BEEa1/dR1Dxn2IHXAgfLGfP
TKr78/bopZTKz/f1d15dyk/k9/3ILSKfG+DQHJmaK23PGKdY4wwn2Njc3OZq
u/d3ymmtxwL3uMQDrvCEazziBq+4xQ53eLGcs+X826tc7dE75WivequHequH
/jOwjTedCB3M
        "]]}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 32.}, {0, 31.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.016666666666666666`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJx1kclKA0EURRtXLl24cOFCQxCREBziHJPKYBwSTfATBNf+Qn2yn6CScwrq
QRqaw6mqrnff68PP74+vraZp0t/7z/XzM2zqJ9Xr26nmTqrP7cK9wP1Azx2E
e1rwGLbhCTyC3XCuE861w3r8zjqnIccZvIHn8BZewHvYg3fwEg7gFRzCa/gQ
6vRDnU33Wtd7/M463mtuc5jbHPaZIHPI+jMcsY5n/YX9McSzPocT1vGsv7I/
hXjW3+Ej63jWl+zPIJ71N/jEOp71Bfv2idtnyWVfuH2bw9wlp04d51Dq6uY0
xyzkGtd9ONfSB3Msc3KuOv+pzMX/pvufVzClX3NaT9w=
        "]]}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 64.}, {0, 63.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
 "Si este c\[OAcute]digo funciona correctamente, el resultado debe contener \
todos los n\[UAcute]meros del 0 al ",
 Cell[BoxData[
  RowBox[{"2", 
   ButtonBox["^",
    BaseStyle->"Link",
    ButtonData->"Power"], "m", 
   ButtonBox["-",
    BaseStyle->"Link",
    ButtonData->"Subtract"], "1"}]], "InlineCode"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", "=", "4"}], "}"}], ",", 
    RowBox[{"Nest", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{"#", ",", 
         RowBox[{
          RowBox[{"Length", "[", "#", "]"}], "+", 
          RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
      RowBox[{"{", "0", "}"}], ",", "m"}], "]"}]}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[6]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", 
   ",", "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
   ",", "15"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
 "Se comprueba esto sistem\[AAcute]ticamente hasta ",
 Cell[BoxData[
  RowBox[{"m", 
   ButtonBox["=",
    BaseStyle->"Link",
    ButtonData->"Set"], "10"}]], "InlineCode"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sort", "[", 
     RowBox[{"Nest", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"#", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "+", 
           RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
       RowBox[{"{", "0", "}"}], ",", "m"}], "]"}], "]"}], "\[Equal]", 
    RowBox[{"Range", "[", 
     RowBox[{"0", ",", 
      RowBox[{
       RowBox[{"2", "^", "m"}], "-", "1"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", "10"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[7]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
 "A veces no basta con ver el resultado final de un fragmento de \
c\[OAcute]digo; hay que asomarse tambi\[EAcute]n a lo que sucede al interior. \
Puede insertarse la funci\[OAcute]n ",
 ButtonBox["Echo",
  BaseStyle->"Link"],
 " en cualquier parte para ver en la pantalla resultados o valores \
intermedios con el c\[OAcute]digo que est\[AAcute] corriendo."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[TextData[{
 ButtonBox["Echo",
  BaseStyle->"Link"],
 " muestra valores, pero no interfiere con el resultado:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Echo", "[", "n", "]"}], "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "3"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[8]:="],

Cell[CellGroupData[{

Cell[BoxData["1"], "Echo"],

Cell[BoxData["2"], "Echo"],

Cell[BoxData["3"], "Echo"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "4", ",", "9"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
 "Si se est\[AAcute] ejecutando un c\[OAcute]mputo largo, se puede supervisar \
el progreso del mismo usando ",
 ButtonBox["Monitor",
  BaseStyle->"Link"],
 ". "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{"p:293", "i:12"}],

Cell[TextData[{
 "Muestre continuamente (con un marco) el valor de ",
 Cell[BoxData["n"], "InlineCode"],
 " que se ha alcanzado hasta el momento:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:13"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PrimeQ", "[", 
      RowBox[{
       RowBox[{"2", "^", 
        RowBox[{"2", "^", "n"}]}], "+", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "15"}], "}"}]}], "]"}], ",", 
   RowBox[{"Framed", "[", "n", "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[9]:="],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztndtzG1cZwEOZAV6ghZCL88Y/wfDU0pYX3po0faMXp01DSwhDmmkHZpph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    "], {{0, 54}, {362, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{109.16796875000011`, Automatic},
  ImageSizeRaw->{362, 54},
  PlotRange->{{0, 362}, {0, 54}}]], "PrintTemporary",
 CellMargins->{{98, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "False", ",", "False", 
   ",", "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Echo",
  BaseStyle->"Link"],
 " y ",
 ButtonBox["Monitor",
  BaseStyle->"Link"],
 " solamente muestran cosas. Si se desea efectivamente capturar los \
resultados intermedios, puede usarse ",
 ButtonBox["Sow",
  BaseStyle->"Link"],
 " (sembrar) y ",
 ButtonBox["Reap ",
  BaseStyle->"Link"],
 "(cosechar)."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:14"],

Cell[TextData[{
 ButtonBox["Reap",
  BaseStyle->"Link"],
 " produce el resultado final junto con una lista de todo lo que fue sembrado \
por ",
 ButtonBox["Sow",
  BaseStyle->"Link"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reap", "[", 
  RowBox[{"Total", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Sow", "[", "n", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "5"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[10]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
 "Esto siembra valores consecutivos de ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Length",
    BaseStyle->"CodeLink"], "[", 
   ButtonBox["#",
    BaseStyle->"Link",
    ButtonData->"Slot"], "]"}]], "InlineCode"],
 ", y cosecha los resultados:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Last", "[", 
  RowBox[{"Reap", "[", 
   RowBox[{"Nest", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"Sow", "[", 
          RowBox[{"Length", "[", "#", "]"}], "]"}], "+", 
         RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
     RowBox[{"{", "0", "}"}], ",", "10"}], "]"}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[11]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
   "1", ",", "2", ",", "4", ",", "8", ",", "16", ",", "32", ",", "64", ",", 
    "128", ",", "256", ",", "512"}], "}"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[11]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vocabulario", "VocabularySection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["With",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        StyleBox["x", "CodeVariableLrg"], 
        ButtonBox["=",
         BaseStyle->"Link",
         ButtonData->"Set"], 
        StyleBox["value", "CodeVariableLrg"]}], "}"}], ",", 
      StyleBox["expr", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "ejecuta ",
     Cell[BoxData[
      StyleBox["expr", "CodeVariable"]], "InlineCode"],
     " dando a ",
     Cell[BoxData[
      StyleBox["x", "CodeVariable"]], "InlineCode"],
     " el valor ",
     Cell[BoxData[
      StyleBox["value", "CodeVariable"]], "InlineCode"],
     " "
    }], "VocabularyText"]},
   {
    RowBox[{
     ButtonBox["Echo",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["expr", "CodeVariableLrg"], "]"}], " ", Cell[TextData[{
     "muestra y regresa el valor de ",
     Cell[BoxData[
      StyleBox["expr", "CodeVariable"]], "InlineCode"],
     " "
    }], "VocabularyText"]},
   {
    RowBox[{
     ButtonBox["Monitor",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["expr", "CodeVariableLrg"], ",", 
      StyleBox["obj", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "muestra continuamente ",
     Cell[BoxData[
      StyleBox["obj", "CodeVariable"]], "InlineCode"],
     " a lo largo de una ejecuci\[OAcute]n "
    }], "VocabularyText"]},
   {
    RowBox[{
     ButtonBox["Sow",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["expr", "CodeVariableLrg"], "]"}], " ", Cell[TextData[{
     "siembra el valor de ",
     Cell[BoxData[
      StyleBox["expr", "CodeVariable"]], "InlineCode"],
     " para cosecharse posteriormente "
    }], "VocabularyText"]},
   {
    RowBox[{
     ButtonBox["Reap",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["expr", "CodeVariableLrg"], "]"}], " ", Cell[TextData[{
     "colecciona los valores sembrados mientras se ejecuta ",
     Cell[BoxData[
      StyleBox["expr", "CodeVariable"]], "InlineCode"],
     " "
    }], "VocabularyText"]}
  }]], "VocabularyTable",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 DynamicModuleBox[{$CellContext`open$$ = False}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"Exercises\"\>",
       StripOnInput->False,
       FontSlant->"Italic"], 
      PaneBox[
       TagBox[
        ButtonBox[
         DynamicBox[ToBoxes[
           If[$CellContext`open$$, 
            Row[{
              Style["-", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}], 
            Row[{
              Style["+", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}]], 
           StandardForm],
          ImageSizeCache->{115., {1., 10.}}],
         Appearance->None,
         ButtonFunction:>(
          If[$CellContext`open$$, $CellContext`open$$ = 
            False, $CellContext`open$$ = True]; NotebookFind[
            EvaluationNotebook[], "ExerciseSummaryCell", Next, CellStyle, 
            WrapAround -> True, AutoScroll -> False]; FrontEndTokenExecute[
            EvaluationNotebook[], "ExpandSelection"]; FrontEndExecute[
            FrontEndToken[
             EvaluationNotebook[], "OpenCloseGroup"]]),
         Evaluator->Automatic,
         Method->"Preemptive"],
        MouseAppearanceTag["LinkHand"]],
       Alignment->Right,
       ImageSize->Full]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "ExerciseSection",
 Editable->False,
 ShowCellBracket->False,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.669991951589675*^9},
 ShowStringCharacters->False],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         PaneBox[
          StyleBox["\<\"3 Exercises Available\"\>", "ExerciseSummaryHeading",
           StripOnInput->False],
          ImageMargins->{{20, 0}, {0, 10}}]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{0}}}],
      "Column"], 
     PaneBox[
      ButtonBox[
       StyleBox["\<\"Get Started \[RightGuillemet]\"\>", 
        "ExerciseSummaryHeading",
        StripOnInput->False],
       Appearance->None,
       ButtonFunction:>
        NotebookLocate[{"EIWL2-47-debugging-your-code-exercises.nb", ""}],
       Evaluator->Automatic,
       Method->"Preemptive"],
      FrameMargins->{{10, 0}, {10, 10}},
      ImageSize->Full]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.7], 
       Scaled[0.3]}, "Rows" -> {{Automatic}}}],
  "Grid"]], "ExerciseSummaryCell",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[CellGroupData[{

Cell[TextData[{
 "Corrija el programa ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Counts",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     ButtonBox["StringTake",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      ButtonBox["#",
       BaseStyle->"Link",
       ButtonData->"Slot"], ",", "2"}], "]"}], 
    ButtonBox["&",
     BaseStyle->"Link",
     ButtonData->"Function"], 
    ButtonBox["/@",
     BaseStyle->"Link",
     ButtonData->"Map"], 
    RowBox[{
     ButtonBox["WordList",
      BaseStyle->"CodeLink"], "[", "]"}]}], "]"}]], "InlineCode"],
 " para contar las primeras dos letras en cada palabra, cuando se pueda.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "47.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"\[LeftAssociation]", 
        RowBox[{
         RowBox[{"\<\"aa\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ab\"\>", "\[Rule]", "174"}], ",", 
         RowBox[{"\<\"ac\"\>", "\[Rule]", "223"}], ",", 
         RowBox[{"\<\"ad\"\>", "\[Rule]", "197"}], ",", 
         RowBox[{"\<\"ae\"\>", "\[Rule]", "28"}], ",", 
         RowBox[{"\<\"af\"\>", "\[Rule]", "73"}], ",", 
         RowBox[{"\<\"ag\"\>", "\[Rule]", "81"}], ",", 
         RowBox[{"\<\"ah\"\>", "\[Rule]", "6"}], ",", 
         RowBox[{"\<\"ai\"\>", "\[Rule]", "57"}], ",", 
         RowBox[{"\<\"aj\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ak\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"al\"\>", "\[Rule]", "208"}], ",", 
         RowBox[{"\<\"am\"\>", "\[Rule]", "140"}], ",", 
         RowBox[{"\<\"an\"\>", "\[Rule]", "333"}], ",", 
         RowBox[{"\<\"ao\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"ap\"\>", "\[Rule]", "168"}], ",", 
         RowBox[{"\<\"aq\"\>", "\[Rule]", "15"}], ",", 
         RowBox[{"\<\"ar\"\>", "\[Rule]", "213"}], ",", 
         RowBox[{"\<\"as\"\>", "\[Rule]", "201"}], ",", 
         RowBox[{"\<\"at\"\>", "\[Rule]", "103"}], ",", 
         RowBox[{"\<\"au\"\>", "\[Rule]", "117"}], ",", 
         RowBox[{"\<\"av\"\>", "\[Rule]", "47"}], ",", 
         RowBox[{"\<\"aw\"\>", "\[Rule]", "31"}], ",", 
         RowBox[{"\<\"ax\"\>", "\[Rule]", "13"}], ",", 
         RowBox[{"\<\"ay\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"az\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"ba\"\>", "\[Rule]", "461"}], ",", 
         RowBox[{"\<\"be\"\>", "\[Rule]", "372"}], ",", 
         RowBox[{"\<\"bi\"\>", "\[Rule]", "214"}], ",", 
         RowBox[{"\<\"bl\"\>", "\[Rule]", "263"}], ",", 
         RowBox[{"\<\"bo\"\>", "\[Rule]", "318"}], ",", 
         RowBox[{"\<\"br\"\>", "\[Rule]", "314"}], ",", 
         RowBox[{"\<\"bu\"\>", "\[Rule]", "267"}], ",", 
         RowBox[{"\<\"by\"\>", "\[Rule]", "14"}], ",", 
         RowBox[{"\<\"ca\"\>", "\[Rule]", "629"}], ",", 
         RowBox[{"\<\"ce\"\>", "\[Rule]", "130"}], ",", 
         RowBox[{"\<\"ch\"\>", "\[Rule]", "453"}], ",", 
         RowBox[{"\<\"ci\"\>", "\[Rule]", "89"}], ",", 
         RowBox[{"\<\"cl\"\>", "\[Rule]", "273"}], ",", 
         RowBox[{"\<\"cn\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"co\"\>", "\[Rule]", "1615"}], ",", 
         RowBox[{"\<\"cr\"\>", "\[Rule]", "350"}], ",", 
         RowBox[{"\<\"cu\"\>", "\[Rule]", "187"}], ",", 
         RowBox[{"\<\"cy\"\>", "\[Rule]", "46"}], ",", 
         RowBox[{"\<\"cz\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"da\"\>", "\[Rule]", "169"}], ",", 
         RowBox[{"\<\"dB\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"de\"\>", "\[Rule]", "905"}], ",", 
         RowBox[{"\<\"dh\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"di\"\>", "\[Rule]", "841"}], ",", 
         RowBox[{"\<\"do\"\>", "\[Rule]", "253"}], ",", 
         RowBox[{"\<\"dr\"\>", "\[Rule]", "174"}], ",", 
         RowBox[{"\<\"du\"\>", "\[Rule]", "120"}], ",", 
         RowBox[{"\<\"dw\"\>", "\[Rule]", "9"}], ",", 
         RowBox[{"\<\"dy\"\>", "\[Rule]", "30"}], ",", 
         RowBox[{"\<\"ea\"\>", "\[Rule]", "73"}], ",", 
         RowBox[{"\<\"eb\"\>", "\[Rule]", "7"}], ",", 
         RowBox[{"\<\"ec\"\>", "\[Rule]", "45"}], ",", 
         RowBox[{"\<\"ed\"\>", "\[Rule]", "40"}], ",", 
         RowBox[{"\<\"ee\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"e'\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ef\"\>", "\[Rule]", "46"}], ",", 
         RowBox[{"\<\"eg\"\>", "\[Rule]", "28"}], ",", 
         RowBox[{"\<\"eh\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ei\"\>", "\[Rule]", "16"}], ",", 
         RowBox[{"\<\"ej\"\>", "\[Rule]", "5"}], ",", 
         RowBox[{"\<\"el\"\>", "\[Rule]", "137"}], ",", 
         RowBox[{"\<\"em\"\>", "\[Rule]", "144"}], ",", 
         RowBox[{"\<\"en\"\>", "\[Rule]", "319"}], ",", 
         RowBox[{"\<\"eo\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ep\"\>", "\[Rule]", "53"}], ",", 
         RowBox[{"\<\"eq\"\>", "\[Rule]", "42"}], ",", 
         RowBox[{"\<\"er\"\>", "\[Rule]", "60"}], ",", 
         RowBox[{"\<\"es\"\>", "\[Rule]", "66"}], ",", 
         RowBox[{"\<\"et\"\>", "\[Rule]", "42"}], ",", 
         RowBox[{"\<\"eu\"\>", "\[Rule]", "25"}], ",", 
         RowBox[{"\<\"ev\"\>", "\[Rule]", "76"}], ",", 
         RowBox[{"\<\"ew\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ex\"\>", "\[Rule]", "419"}], ",", 
         RowBox[{"\<\"ey\"\>", "\[Rule]", "21"}], ",", 
         RowBox[{"\<\"fa\"\>", "\[Rule]", "286"}], ",", 
         RowBox[{"\<\"fe\"\>", "\[Rule]", "176"}], ",", 
         RowBox[{"\<\"fi\"\>", "\[Rule]", "258"}], ",", 
         RowBox[{"\<\"fj\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"fl\"\>", "\[Rule]", "273"}], ",", 
         RowBox[{"\<\"fo\"\>", "\[Rule]", "344"}], ",", 
         RowBox[{"\<\"fr\"\>", "\[Rule]", "238"}], ",", 
         RowBox[{"\<\"fu\"\>", "\[Rule]", "140"}], ",", 
         RowBox[{"\<\"ga\"\>", "\[Rule]", "206"}], ",", 
         RowBox[{"\<\"ge\"\>", "\[Rule]", "158"}], ",", 
         RowBox[{"\<\"gh\"\>", "\[Rule]", "15"}], ",", 
         RowBox[{"\<\"gi\"\>", "\[Rule]", "66"}], ",", 
         RowBox[{"\<\"gl\"\>", "\[Rule]", "138"}], ",", 
         RowBox[{"\<\"gn\"\>", "\[Rule]", "13"}], ",", 
         RowBox[{"\<\"go\"\>", "\[Rule]", "128"}], ",", 
         RowBox[{"\<\"gr\"\>", "\[Rule]", "355"}], ",", 
         RowBox[{"\<\"gu\"\>", "\[Rule]", "123"}], ",", 
         RowBox[{"\<\"gy\"\>", "\[Rule]", "21"}], ",", 
         RowBox[{"\<\"ha\"\>", "\[Rule]", "373"}], ",", 
         RowBox[{"\<\"he\"\>", "\[Rule]", "333"}], ",", 
         RowBox[{"\<\"hi\"\>", "\[Rule]", "130"}], ",", 
         RowBox[{"\<\"h'\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"hm\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ho\"\>", "\[Rule]", "349"}], ",", 
         RowBox[{"\<\"hu\"\>", "\[Rule]", "141"}], ",", 
         RowBox[{"\<\"hy\"\>", "\[Rule]", "118"}], ",", 
         RowBox[{"\<\"ia\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"ib\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"ic\"\>", "\[Rule]", "27"}], ",", 
         RowBox[{"\<\"id\"\>", "\[Rule]", "56"}], ",", 
         RowBox[{"\<\"if\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ig\"\>", "\[Rule]", "18"}], ",", 
         RowBox[{"\<\"il\"\>", "\[Rule]", "55"}], ",", 
         RowBox[{"\<\"im\"\>", "\[Rule]", "329"}], ",", 
         RowBox[{"\<\"in\"\>", "\[Rule]", "1261"}], ",", 
         RowBox[{"\<\"io\"\>", "\[Rule]", "11"}], ",", 
         RowBox[{"\<\"ip\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ir\"\>", "\[Rule]", "90"}], ",", 
         RowBox[{"\<\"is\"\>", "\[Rule]", "35"}], ",", 
         RowBox[{"\<\"it\"\>", "\[Rule]", "17"}], ",", 
         RowBox[{"\<\"iv\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"ja\"\>", "\[Rule]", "75"}], ",", 
         RowBox[{"\<\"je\"\>", "\[Rule]", "47"}], ",", 
         RowBox[{"\<\"ji\"\>", "\[Rule]", "32"}], ",", 
         RowBox[{"\<\"jo\"\>", "\[Rule]", "78"}], ",", 
         RowBox[{"\<\"ju\"\>", "\[Rule]", "87"}], ",", 
         RowBox[{"\<\"ka\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"kc\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ke\"\>", "\[Rule]", "40"}], ",", 
         RowBox[{"\<\"kh\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"kH\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ki\"\>", "\[Rule]", "89"}], ",", 
         RowBox[{"\<\"kl\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"kn\"\>", "\[Rule]", "54"}], ",", 
         RowBox[{"\<\"ko\"\>", "\[Rule]", "10"}], ",", 
         RowBox[{"\<\"kp\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"kr\"\>", "\[Rule]", "5"}], ",", 
         RowBox[{"\<\"ku\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"kv\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"kW\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"la\"\>", "\[Rule]", "310"}], ",", 
         RowBox[{"\<\"le\"\>", "\[Rule]", "229"}], ",", 
         RowBox[{"\<\"li\"\>", "\[Rule]", "303"}], ",", 
         RowBox[{"\<\"ll\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"lo\"\>", "\[Rule]", "232"}], ",", 
         RowBox[{"\<\"lu\"\>", "\[Rule]", "111"}], ",", 
         RowBox[{"\<\"ly\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"ma\"\>", "\[Rule]", "606"}], ",", 
         RowBox[{"\<\"me\"\>", "\[Rule]", "373"}], ",", 
         RowBox[{"\<\"mi\"\>", "\[Rule]", "421"}], ",", 
         RowBox[{"\<\"mn\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"mo\"\>", "\[Rule]", "402"}], ",", 
         RowBox[{"\<\"ms\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"mu\"\>", "\[Rule]", "211"}], ",", 
         RowBox[{"\<\"my\"\>", "\[Rule]", "33"}], ",", 
         RowBox[{"\<\"na\"\>", "\[Rule]", "132"}], ",", 
         RowBox[{"\<\"ne\"\>", "\[Rule]", "216"}], ",", 
         RowBox[{"\<\"ni\"\>", "\[Rule]", "94"}], ",", 
         RowBox[{"\<\"no\"\>", "\[Rule]", "312"}], ",", 
         RowBox[{"\<\"nt\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"nu\"\>", "\[Rule]", "90"}], ",", 
         RowBox[{"\<\"ny\"\>", "\[Rule]", "8"}], ",", 
         RowBox[{"\<\"oa\"\>", "\[Rule]", "16"}], ",", 
         RowBox[{"\<\"ob\"\>", "\[Rule]", "131"}], ",", 
         RowBox[{"\<\"oc\"\>", "\[Rule]", "46"}], ",", 
         RowBox[{"\<\"o'\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"od\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"oe\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"of\"\>", "\[Rule]", "48"}], ",", 
         RowBox[{"\<\"og\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"oh\"\>", "\[Rule]", "5"}], ",", 
         RowBox[{"\<\"oi\"\>", "\[Rule]", "12"}], ",", 
         RowBox[{"\<\"ok\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"ol\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"om\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"on\"\>", "\[Rule]", "35"}], ",", 
         RowBox[{"\<\"oo\"\>", "\[Rule]", "7"}], ",", 
         RowBox[{"\<\"op\"\>", "\[Rule]", "86"}], ",", 
         RowBox[{"\<\"or\"\>", "\[Rule]", "118"}], ",", 
         RowBox[{"\<\"os\"\>", "\[Rule]", "29"}], ",", 
         RowBox[{"\<\"ot\"\>", "\[Rule]", "7"}], ",", 
         RowBox[{"\<\"ou\"\>", "\[Rule]", "127"}], ",", 
         RowBox[{"\<\"ov\"\>", "\[Rule]", "224"}], ",", 
         RowBox[{"\<\"ow\"\>", "\[Rule]", "11"}], ",", 
         RowBox[{"\<\"ox\"\>", "\[Rule]", "19"}], ",", 
         RowBox[{"\<\"oy\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"oz\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"pa\"\>", "\[Rule]", "570"}], ",", 
         RowBox[{"\<\"pe\"\>", "\[Rule]", "503"}], ",", 
         RowBox[{"\<\"pf\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"pH\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ph\"\>", "\[Rule]", "163"}], ",", 
         RowBox[{"\<\"pi\"\>", "\[Rule]", "223"}], ",", 
         RowBox[{"\<\"pl\"\>", "\[Rule]", "232"}], ",", 
         RowBox[{"\<\"pn\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"po\"\>", "\[Rule]", "419"}], ",", 
         RowBox[{"\<\"pr\"\>", "\[Rule]", "839"}], ",", 
         RowBox[{"\<\"ps\"\>", "\[Rule]", "53"}], ",", 
         RowBox[{"\<\"pt\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"pu\"\>", "\[Rule]", "234"}], ",", 
         RowBox[{"\<\"py\"\>", "\[Rule]", "22"}], ",", 
         RowBox[{"\<\"qu\"\>", "\[Rule]", "197"}], ",", 
         RowBox[{"\<\"ra\"\>", "\[Rule]", "319"}], ",", 
         RowBox[{"\<\"re\"\>", "\[Rule]", "1242"}], ",", 
         RowBox[{"\<\"rh\"\>", "\[Rule]", "39"}], ",", 
         RowBox[{"\<\"ri\"\>", "\[Rule]", "151"}], ",", 
         RowBox[{"\<\"ro\"\>", "\[Rule]", "212"}], ",", 
         RowBox[{"\<\"ru\"\>", "\[Rule]", "128"}], ",", 
         RowBox[{"\<\"ry\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"sa\"\>", "\[Rule]", "330"}], ",", 
         RowBox[{"\<\"sc\"\>", "\[Rule]", "347"}], ",", 
         RowBox[{"\<\"se\"\>", "\[Rule]", "569"}], ",", 
         RowBox[{"\<\"sh\"\>", "\[Rule]", "386"}], ",", 
         RowBox[{"\<\"si\"\>", "\[Rule]", "250"}], ",", 
         RowBox[{"\<\"sk\"\>", "\[Rule]", "98"}], ",", 
         RowBox[{"\<\"sl\"\>", "\[Rule]", "205"}], ",", 
         RowBox[{"\<\"sm\"\>", "\[Rule]", "81"}], ",", 
         RowBox[{"\<\"sn\"\>", "\[Rule]", "120"}], ",", 
         RowBox[{"\<\"so\"\>", "\[Rule]", "311"}], ",", 
         RowBox[{"\<\"sp\"\>", "\[Rule]", "418"}], ",", 
         RowBox[{"\<\"sq\"\>", "\[Rule]", "62"}], ",", 
         RowBox[{"\<\"st\"\>", "\[Rule]", "709"}], ",", 
         RowBox[{"\<\"su\"\>", "\[Rule]", "530"}], ",", 
         RowBox[{"\<\"sv\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"sw\"\>", "\[Rule]", "121"}], ",", 
         RowBox[{"\<\"sy\"\>", "\[Rule]", "104"}], ",", 
         RowBox[{"\<\"ta\"\>", "\[Rule]", "280"}], ",", 
         RowBox[{"\<\"te\"\>", "\[Rule]", "326"}], ",", 
         RowBox[{"\<\"th\"\>", "\[Rule]", "290"}], ",", 
         RowBox[{"\<\"ti\"\>", "\[Rule]", "173"}], ",", 
         RowBox[{"\<\"to\"\>", "\[Rule]", "263"}], ",", 
         RowBox[{"\<\"tr\"\>", "\[Rule]", "485"}], ",", 
         RowBox[{"\<\"ts\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"tu\"\>", "\[Rule]", "122"}], ",", 
         RowBox[{"\<\"tw\"\>", "\[Rule]", "53"}], ",", 
         RowBox[{"\<\"ty\"\>", "\[Rule]", "43"}], ",", 
         RowBox[{"\<\"ub\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ud\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ug\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"uk\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ul\"\>", "\[Rule]", "24"}], ",", 
         RowBox[{"\<\"um\"\>", "\[Rule]", "14"}], ",", 
         RowBox[{"\<\"un\"\>", "\[Rule]", "1353"}], ",", 
         RowBox[{"\<\"up\"\>", "\[Rule]", "75"}], ",", 
         RowBox[{"\<\"ur\"\>", "\[Rule]", "36"}], ",", 
         RowBox[{"\<\"us\"\>", "\[Rule]", "25"}], ",", 
         RowBox[{"\<\"ut\"\>", "\[Rule]", "18"}], ",", 
         RowBox[{"\<\"uv\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ux\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"va\"\>", "\[Rule]", "149"}], ",", 
         RowBox[{"\<\"ve\"\>", "\[Rule]", "173"}], ",", 
         RowBox[{"\<\"vi\"\>", "\[Rule]", "219"}], ",", 
         RowBox[{"\<\"vo\"\>", "\[Rule]", "87"}], ",", 
         RowBox[{"\<\"vu\"\>", "\[Rule]", "18"}], ",", 
         RowBox[{"\<\"wa\"\>", "\[Rule]", "262"}], ",", 
         RowBox[{"\<\"we\"\>", "\[Rule]", "132"}], ",", 
         RowBox[{"\<\"wh\"\>", "\[Rule]", "173"}], ",", 
         RowBox[{"\<\"wi\"\>", "\[Rule]", "196"}], ",", 
         RowBox[{"\<\"wo\"\>", "\[Rule]", "174"}], ",", 
         RowBox[{"\<\"wr\"\>", "\[Rule]", "69"}], ",", 
         RowBox[{"\<\"wu\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"xe\"\>", "\[Rule]", "6"}], ",", 
         RowBox[{"\<\"xi\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"xy\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"ya\"\>", "\[Rule]", "28"}], ",", 
         RowBox[{"\<\"ye\"\>", "\[Rule]", "36"}], ",", 
         RowBox[{"\<\"yi\"\>", "\[Rule]", "8"}], ",", 
         RowBox[{"\<\"yo\"\>", "\[Rule]", "28"}], ",", 
         RowBox[{"\<\"yt\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"yu\"\>", "\[Rule]", "7"}], ",", 
         RowBox[{"\<\"za\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"ze\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"zi\"\>", "\[Rule]", "15"}], ",", 
         RowBox[{"\<\"zl\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"zo\"\>", "\[Rule]", "13"}], ",", 
         RowBox[{"\<\"zu\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"zw\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"zy\"\>", "\[Rule]", "4"}]}], "\[RightAssociation]"}]], 
       "ExerciseOutput"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"\[LeftAssociation]", 
           RowBox[{
             RowBox[{"\"aa\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ab\"", "\[Rule]", "174"}], ",", 
             RowBox[{"\"ac\"", "\[Rule]", "223"}], ",", 
             RowBox[{"\"ad\"", "\[Rule]", "197"}], ",", 
             RowBox[{"\"ae\"", "\[Rule]", "28"}], ",", 
             RowBox[{"\"af\"", "\[Rule]", "73"}], ",", 
             RowBox[{"\"ag\"", "\[Rule]", "81"}], ",", 
             RowBox[{"\"ah\"", "\[Rule]", "6"}], ",", 
             RowBox[{"\"ai\"", "\[Rule]", "57"}], ",", 
             RowBox[{"\"aj\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ak\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"al\"", "\[Rule]", "208"}], ",", 
             RowBox[{"\"am\"", "\[Rule]", "140"}], ",", 
             RowBox[{"\"an\"", "\[Rule]", "333"}], ",", 
             RowBox[{"\"ao\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"ap\"", "\[Rule]", "168"}], ",", 
             RowBox[{"\"aq\"", "\[Rule]", "15"}], ",", 
             RowBox[{"\"ar\"", "\[Rule]", "213"}], ",", 
             RowBox[{"\"as\"", "\[Rule]", "201"}], ",", 
             RowBox[{"\"at\"", "\[Rule]", "103"}], ",", 
             RowBox[{"\"au\"", "\[Rule]", "117"}], ",", 
             RowBox[{"\"av\"", "\[Rule]", "47"}], ",", 
             RowBox[{"\"aw\"", "\[Rule]", "31"}], ",", 
             RowBox[{"\"ax\"", "\[Rule]", "13"}], ",", 
             RowBox[{"\"ay\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"az\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"ba\"", "\[Rule]", "461"}], ",", 
             RowBox[{"\"be\"", "\[Rule]", "372"}], ",", 
             RowBox[{"\"bi\"", "\[Rule]", "214"}], ",", 
             RowBox[{"\"bl\"", "\[Rule]", "263"}], ",", 
             RowBox[{"\"bo\"", "\[Rule]", "318"}], ",", 
             RowBox[{"\"br\"", "\[Rule]", "314"}], ",", 
             RowBox[{"\"bu\"", "\[Rule]", "267"}], ",", 
             RowBox[{"\"by\"", "\[Rule]", "14"}], ",", 
             RowBox[{"\"ca\"", "\[Rule]", "629"}], ",", 
             RowBox[{"\"ce\"", "\[Rule]", "130"}], ",", 
             RowBox[{"\"ch\"", "\[Rule]", "453"}], ",", 
             RowBox[{"\"ci\"", "\[Rule]", "89"}], ",", 
             RowBox[{"\"cl\"", "\[Rule]", "273"}], ",", 
             RowBox[{"\"cn\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"co\"", "\[Rule]", "1615"}], ",", 
             RowBox[{"\"cr\"", "\[Rule]", "350"}], ",", 
             RowBox[{"\"cu\"", "\[Rule]", "187"}], ",", 
             RowBox[{"\"cy\"", "\[Rule]", "46"}], ",", 
             RowBox[{"\"cz\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"da\"", "\[Rule]", "169"}], ",", 
             RowBox[{"\"dB\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"de\"", "\[Rule]", "905"}], ",", 
             RowBox[{"\"dh\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"di\"", "\[Rule]", "841"}], ",", 
             RowBox[{"\"do\"", "\[Rule]", "253"}], ",", 
             RowBox[{"\"dr\"", "\[Rule]", "174"}], ",", 
             RowBox[{"\"du\"", "\[Rule]", "120"}], ",", 
             RowBox[{"\"dw\"", "\[Rule]", "9"}], ",", 
             RowBox[{"\"dy\"", "\[Rule]", "30"}], ",", 
             RowBox[{"\"ea\"", "\[Rule]", "73"}], ",", 
             RowBox[{"\"eb\"", "\[Rule]", "7"}], ",", 
             RowBox[{"\"ec\"", "\[Rule]", "45"}], ",", 
             RowBox[{"\"ed\"", "\[Rule]", "40"}], ",", 
             RowBox[{"\"ee\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"e'\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ef\"", "\[Rule]", "46"}], ",", 
             RowBox[{"\"eg\"", "\[Rule]", "28"}], ",", 
             RowBox[{"\"eh\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ei\"", "\[Rule]", "16"}], ",", 
             RowBox[{"\"ej\"", "\[Rule]", "5"}], ",", 
             RowBox[{"\"el\"", "\[Rule]", "137"}], ",", 
             RowBox[{"\"em\"", "\[Rule]", "144"}], ",", 
             RowBox[{"\"en\"", "\[Rule]", "319"}], ",", 
             RowBox[{"\"eo\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ep\"", "\[Rule]", "53"}], ",", 
             RowBox[{"\"eq\"", "\[Rule]", "42"}], ",", 
             RowBox[{"\"er\"", "\[Rule]", "60"}], ",", 
             RowBox[{"\"es\"", "\[Rule]", "66"}], ",", 
             RowBox[{"\"et\"", "\[Rule]", "42"}], ",", 
             RowBox[{"\"eu\"", "\[Rule]", "25"}], ",", 
             RowBox[{"\"ev\"", "\[Rule]", "76"}], ",", 
             RowBox[{"\"ew\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ex\"", "\[Rule]", "419"}], ",", 
             RowBox[{"\"ey\"", "\[Rule]", "21"}], ",", 
             RowBox[{"\"fa\"", "\[Rule]", "286"}], ",", 
             RowBox[{"\"fe\"", "\[Rule]", "176"}], ",", 
             RowBox[{"\"fi\"", "\[Rule]", "258"}], ",", 
             RowBox[{"\"fj\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"fl\"", "\[Rule]", "273"}], ",", 
             RowBox[{"\"fo\"", "\[Rule]", "344"}], ",", 
             RowBox[{"\"fr\"", "\[Rule]", "238"}], ",", 
             RowBox[{"\"fu\"", "\[Rule]", "140"}], ",", 
             RowBox[{"\"ga\"", "\[Rule]", "206"}], ",", 
             RowBox[{"\"ge\"", "\[Rule]", "158"}], ",", 
             RowBox[{"\"gh\"", "\[Rule]", "15"}], ",", 
             RowBox[{"\"gi\"", "\[Rule]", "66"}], ",", 
             RowBox[{"\"gl\"", "\[Rule]", "138"}], ",", 
             RowBox[{"\"gn\"", "\[Rule]", "13"}], ",", 
             RowBox[{"\"go\"", "\[Rule]", "128"}], ",", 
             RowBox[{"\"gr\"", "\[Rule]", "355"}], ",", 
             RowBox[{"\"gu\"", "\[Rule]", "123"}], ",", 
             RowBox[{"\"gy\"", "\[Rule]", "21"}], ",", 
             RowBox[{"\"ha\"", "\[Rule]", "373"}], ",", 
             RowBox[{"\"he\"", "\[Rule]", "333"}], ",", 
             RowBox[{"\"hi\"", "\[Rule]", "130"}], ",", 
             RowBox[{"\"h'\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"hm\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ho\"", "\[Rule]", "349"}], ",", 
             RowBox[{"\"hu\"", "\[Rule]", "141"}], ",", 
             RowBox[{"\"hy\"", "\[Rule]", "118"}], ",", 
             RowBox[{"\"ia\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"ib\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"ic\"", "\[Rule]", "27"}], ",", 
             RowBox[{"\"id\"", "\[Rule]", "56"}], ",", 
             RowBox[{"\"if\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ig\"", "\[Rule]", "18"}], ",", 
             RowBox[{"\"il\"", "\[Rule]", "55"}], ",", 
             RowBox[{"\"im\"", "\[Rule]", "329"}], ",", 
             RowBox[{"\"in\"", "\[Rule]", "1261"}], ",", 
             RowBox[{"\"io\"", "\[Rule]", "11"}], ",", 
             RowBox[{"\"ip\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ir\"", "\[Rule]", "90"}], ",", 
             RowBox[{"\"is\"", "\[Rule]", "35"}], ",", 
             RowBox[{"\"it\"", "\[Rule]", "17"}], ",", 
             RowBox[{"\"iv\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"ja\"", "\[Rule]", "75"}], ",", 
             RowBox[{"\"je\"", "\[Rule]", "47"}], ",", 
             RowBox[{"\"ji\"", "\[Rule]", "32"}], ",", 
             RowBox[{"\"jo\"", "\[Rule]", "78"}], ",", 
             RowBox[{"\"ju\"", "\[Rule]", "87"}], ",", 
             RowBox[{"\"ka\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"kc\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ke\"", "\[Rule]", "40"}], ",", 
             RowBox[{"\"kh\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"kH\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ki\"", "\[Rule]", "89"}], ",", 
             RowBox[{"\"kl\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"kn\"", "\[Rule]", "54"}], ",", 
             RowBox[{"\"ko\"", "\[Rule]", "10"}], ",", 
             RowBox[{"\"kp\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"kr\"", "\[Rule]", "5"}], ",", 
             RowBox[{"\"ku\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"kv\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"kW\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"la\"", "\[Rule]", "310"}], ",", 
             RowBox[{"\"le\"", "\[Rule]", "229"}], ",", 
             RowBox[{"\"li\"", "\[Rule]", "303"}], ",", 
             RowBox[{"\"ll\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"lo\"", "\[Rule]", "232"}], ",", 
             RowBox[{"\"lu\"", "\[Rule]", "111"}], ",", 
             RowBox[{"\"ly\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"ma\"", "\[Rule]", "606"}], ",", 
             RowBox[{"\"me\"", "\[Rule]", "373"}], ",", 
             RowBox[{"\"mi\"", "\[Rule]", "421"}], ",", 
             RowBox[{"\"mn\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"mo\"", "\[Rule]", "402"}], ",", 
             RowBox[{"\"ms\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"mu\"", "\[Rule]", "211"}], ",", 
             RowBox[{"\"my\"", "\[Rule]", "33"}], ",", 
             RowBox[{"\"na\"", "\[Rule]", "132"}], ",", 
             RowBox[{"\"ne\"", "\[Rule]", "216"}], ",", 
             RowBox[{"\"ni\"", "\[Rule]", "94"}], ",", 
             RowBox[{"\"no\"", "\[Rule]", "312"}], ",", 
             RowBox[{"\"nt\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"nu\"", "\[Rule]", "90"}], ",", 
             RowBox[{"\"ny\"", "\[Rule]", "8"}], ",", 
             RowBox[{"\"oa\"", "\[Rule]", "16"}], ",", 
             RowBox[{"\"ob\"", "\[Rule]", "131"}], ",", 
             RowBox[{"\"oc\"", "\[Rule]", "46"}], ",", 
             RowBox[{"\"o'\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"od\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"oe\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"of\"", "\[Rule]", "48"}], ",", 
             RowBox[{"\"og\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"oh\"", "\[Rule]", "5"}], ",", 
             RowBox[{"\"oi\"", "\[Rule]", "12"}], ",", 
             RowBox[{"\"ok\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"ol\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"om\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"on\"", "\[Rule]", "35"}], ",", 
             RowBox[{"\"oo\"", "\[Rule]", "7"}], ",", 
             RowBox[{"\"op\"", "\[Rule]", "86"}], ",", 
             RowBox[{"\"or\"", "\[Rule]", "118"}], ",", 
             RowBox[{"\"os\"", "\[Rule]", "29"}], ",", 
             RowBox[{"\"ot\"", "\[Rule]", "7"}], ",", 
             RowBox[{"\"ou\"", "\[Rule]", "127"}], ",", 
             RowBox[{"\"ov\"", "\[Rule]", "224"}], ",", 
             RowBox[{"\"ow\"", "\[Rule]", "11"}], ",", 
             RowBox[{"\"ox\"", "\[Rule]", "19"}], ",", 
             RowBox[{"\"oy\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"oz\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"pa\"", "\[Rule]", "570"}], ",", 
             RowBox[{"\"pe\"", "\[Rule]", "503"}], ",", 
             RowBox[{"\"pf\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"pH\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ph\"", "\[Rule]", "163"}], ",", 
             RowBox[{"\"pi\"", "\[Rule]", "223"}], ",", 
             RowBox[{"\"pl\"", "\[Rule]", "232"}], ",", 
             RowBox[{"\"pn\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"po\"", "\[Rule]", "419"}], ",", 
             RowBox[{"\"pr\"", "\[Rule]", "839"}], ",", 
             RowBox[{"\"ps\"", "\[Rule]", "53"}], ",", 
             RowBox[{"\"pt\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"pu\"", "\[Rule]", "234"}], ",", 
             RowBox[{"\"py\"", "\[Rule]", "22"}], ",", 
             RowBox[{"\"qu\"", "\[Rule]", "197"}], ",", 
             RowBox[{"\"ra\"", "\[Rule]", "319"}], ",", 
             RowBox[{"\"re\"", "\[Rule]", "1242"}], ",", 
             RowBox[{"\"rh\"", "\[Rule]", "39"}], ",", 
             RowBox[{"\"ri\"", "\[Rule]", "151"}], ",", 
             RowBox[{"\"ro\"", "\[Rule]", "212"}], ",", 
             RowBox[{"\"ru\"", "\[Rule]", "128"}], ",", 
             RowBox[{"\"ry\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"sa\"", "\[Rule]", "330"}], ",", 
             RowBox[{"\"sc\"", "\[Rule]", "347"}], ",", 
             RowBox[{"\"se\"", "\[Rule]", "569"}], ",", 
             RowBox[{"\"sh\"", "\[Rule]", "386"}], ",", 
             RowBox[{"\"si\"", "\[Rule]", "250"}], ",", 
             RowBox[{"\"sk\"", "\[Rule]", "98"}], ",", 
             RowBox[{"\"sl\"", "\[Rule]", "205"}], ",", 
             RowBox[{"\"sm\"", "\[Rule]", "81"}], ",", 
             RowBox[{"\"sn\"", "\[Rule]", "120"}], ",", 
             RowBox[{"\"so\"", "\[Rule]", "311"}], ",", 
             RowBox[{"\"sp\"", "\[Rule]", "418"}], ",", 
             RowBox[{"\"sq\"", "\[Rule]", "62"}], ",", 
             RowBox[{"\"st\"", "\[Rule]", "709"}], ",", 
             RowBox[{"\"su\"", "\[Rule]", "530"}], ",", 
             RowBox[{"\"sv\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"sw\"", "\[Rule]", "121"}], ",", 
             RowBox[{"\"sy\"", "\[Rule]", "104"}], ",", 
             RowBox[{"\"ta\"", "\[Rule]", "280"}], ",", 
             RowBox[{"\"te\"", "\[Rule]", "326"}], ",", 
             RowBox[{"\"th\"", "\[Rule]", "290"}], ",", 
             RowBox[{"\"ti\"", "\[Rule]", "173"}], ",", 
             RowBox[{"\"to\"", "\[Rule]", "263"}], ",", 
             RowBox[{"\"tr\"", "\[Rule]", "485"}], ",", 
             RowBox[{"\"ts\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"tu\"", "\[Rule]", "122"}], ",", 
             RowBox[{"\"tw\"", "\[Rule]", "53"}], ",", 
             RowBox[{"\"ty\"", "\[Rule]", "43"}], ",", 
             RowBox[{"\"ub\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ud\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ug\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"uk\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ul\"", "\[Rule]", "24"}], ",", 
             RowBox[{"\"um\"", "\[Rule]", "14"}], ",", 
             RowBox[{"\"un\"", "\[Rule]", "1353"}], ",", 
             RowBox[{"\"up\"", "\[Rule]", "75"}], ",", 
             RowBox[{"\"ur\"", "\[Rule]", "36"}], ",", 
             RowBox[{"\"us\"", "\[Rule]", "25"}], ",", 
             RowBox[{"\"ut\"", "\[Rule]", "18"}], ",", 
             RowBox[{"\"uv\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ux\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"va\"", "\[Rule]", "149"}], ",", 
             RowBox[{"\"ve\"", "\[Rule]", "173"}], ",", 
             RowBox[{"\"vi\"", "\[Rule]", "219"}], ",", 
             RowBox[{"\"vo\"", "\[Rule]", "87"}], ",", 
             RowBox[{"\"vu\"", "\[Rule]", "18"}], ",", 
             RowBox[{"\"wa\"", "\[Rule]", "262"}], ",", 
             RowBox[{"\"we\"", "\[Rule]", "132"}], ",", 
             RowBox[{"\"wh\"", "\[Rule]", "173"}], ",", 
             RowBox[{"\"wi\"", "\[Rule]", "196"}], ",", 
             RowBox[{"\"wo\"", "\[Rule]", "174"}], ",", 
             RowBox[{"\"wr\"", "\[Rule]", "69"}], ",", 
             RowBox[{"\"wu\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"xe\"", "\[Rule]", "6"}], ",", 
             RowBox[{"\"xi\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"xy\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"ya\"", "\[Rule]", "28"}], ",", 
             RowBox[{"\"ye\"", "\[Rule]", "36"}], ",", 
             RowBox[{"\"yi\"", "\[Rule]", "8"}], ",", 
             RowBox[{"\"yo\"", "\[Rule]", "28"}], ",", 
             RowBox[{"\"yt\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"yu\"", "\[Rule]", "7"}], ",", 
             RowBox[{"\"za\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"ze\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"zi\"", "\[Rule]", "15"}], ",", 
             RowBox[{"\"zl\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"zo\"", "\[Rule]", "13"}], ",", 
             RowBox[{"\"zu\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"zw\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"zy\"", "\[Rule]", "4"}]}], "\[RightAssociation]"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->Automatic]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use ",
 ButtonBox["Sow",
  BaseStyle->"Link"],
 " y ",
 ButtonBox["Reap",
  BaseStyle->"Link"],
 " para obtener los valores intermedios de ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["#",
    BaseStyle->"Link",
    ButtonData->"Slot"], "1"}]], "InlineCode"],
 " en ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Fold",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{"10", 
     ButtonBox["#",
      BaseStyle->"Link",
      ButtonData->"Slot"], "1", 
     ButtonBox["+",
      BaseStyle->"Link",
      ButtonData->"Plus"], 
     ButtonBox["#",
      BaseStyle->"Link",
      ButtonData->"Slot"], "2", 
     ButtonBox["&",
      BaseStyle->"Link",
      ButtonData->"Function"]}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}]}], "]"}]], 
  "InlineCode"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "47.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"1", ",", "12", ",", "123", ",", "1234"}], "}"}]], 
       "ExerciseOutput"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{"1", ",", "12", ",", "123", ",", "1234"}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->Automatic]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use ",
 ButtonBox["Sow",
  BaseStyle->"Link"],
 " y ",
 ButtonBox["Reap",
  BaseStyle->"Link"],
 " para obtener la lista de los casos donde se use ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["#",
    BaseStyle->"Link",
    ButtonData->"Slot"], "/", "2"}]], "InlineCode"],
 " en ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Nest",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      ButtonBox["If",
       BaseStyle->"CodeLink"], "[", 
      RowBox[{
       RowBox[{
        ButtonBox["EvenQ",
         BaseStyle->"CodeLink"], "[", 
        ButtonBox["#",
         BaseStyle->"Link",
         ButtonData->"Slot"], "]"}], ",", 
       RowBox[{
        ButtonBox["#",
         BaseStyle->"Link",
         ButtonData->"Slot"], "/", "2"}], ",", 
       RowBox[{"3", 
        ButtonBox["#",
         BaseStyle->"Link",
         ButtonData->"Slot"], 
        ButtonBox["+",
         BaseStyle->"Link",
         ButtonData->"Plus"], "1"}]}], "]"}], 
     ButtonBox["&",
      BaseStyle->"Link",
      ButtonData->"Function"]}], ",", "1000", ",", "20"}], "]"}]], 
  "InlineCode"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "47.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False,
 CellTags->"LastCellOfAPage"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
        "1000", ",", "500", ",", "250", ",", "376", ",", "188", ",", "94", 
         ",", "142", ",", "214", ",", "322", ",", "484", ",", "242", ",", 
         "364", ",", "182"}], "}"}]], "ExerciseOutput"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"1000", ",", "500", ",", "250", ",", "376", ",", "188", 
             ",", "94", ",", "142", ",", "214", ",", "322", ",", "484", ",", 
             "242", ",", "364", ",", "182"}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->Automatic]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preguntas y respuestas", "QASection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:294"],

Cell["\<\
\[DownQuestion]Puede surgir alg\[UAcute]n problema si se trata de ejecutar \
solamente un fragmento del c\[OAcute]digo?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[TextData[{
 "No, a menos que, por ejemplo, el c\[OAcute]digo est\[EAcute] hecho de modo \
que vaya a eliminar alguna cosa. Wolfram Language tiene protecci\[OAcute]n \
contra bucles infinitos \[OpenCurlyDoubleQuote]obviamente err\[OAcute]neos\
\[CloseCurlyDoubleQuote] y cosas de ese tipo. Si algo tarda demasiado en \
terminar, siempre puede abortarse. Si hay alguna preocupaci\[OAcute]n seria \
respecto del uso de los recursos, se puede usar ",
 ButtonBox["TimeConstrained",
  BaseStyle->"Link"],
 " y ",
 ButtonBox["MemoryConstrained",
  BaseStyle->"Link"],
 "."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:15"],

Cell["\<\
\[DownQuestion]Hay alg\[UAcute]n error que sea muy frecuente al escribir c\
\[OAcute]digo en Wolfram Language?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[TextData[{
 "Realmente, no. El dise\[NTilde]o del lenguaje es tal que son raros los \
errores que en otros lenguajes son de lo m\[AAcute]s com\[UAcute]n. Por \
ejemplo, los errores del tipo \[OpenCurlyDoubleQuote]falt\[OAcute] uno o sobr\
\[OAcute] uno\[CloseCurlyDoubleQuote] son frecuentes en los lenguajes donde \
hay que meterse a manipular expl\[IAcute]citamente las variables de un bucle; \
en Wolfram Language, esto no suele ocurrir al usar funciones para \
\[OpenCurlyDoubleQuote]toda la lista\[CloseCurlyDoubleQuote], como p .ej., ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 "."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:16"],

Cell["\<\
Si no se encuentra lo que est\[AAcute] sucediendo mal, \[DownQuestion]vale la \
pena intentar cosas al azar?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell["\<\
Si se piensa que ya est\[AAcute] cerca de descubrir lo que va mal, quiz\
\[AAcute] no sea mala idea hacer en el c\[OAcute]digo peque\[NTilde]os \
cambios al azar y ver qu\[EAcute] sucede. Dado que en Wolfram Language el c\
\[OAcute]digo simple suele ser el correcto, no es raro que se logre resolver \
el problema mediante un poco de b\[UAcute]squeda al azar.\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:17"],

Cell["\<\
\[DownQuestion]Hay en Wolfram Language alguna manera de depurar \
interactivamente, paso a paso?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell["\<\
S\[IAcute] (al menos con una interfaz basada en una computadora de \
escritorio), aunque se usa muy poco. Dada la estructura de Wolfram Language, \
suele ser mejor un enfoque sistem\[AAcute]tico de captura y an\[AAcute]lisis \
de resultados intermedios.\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:18"],

Cell["\<\
\[DownQuestion]C\[OAcute]mo saber qu\[EAcute] va mal cuando alguna parte de \
una gr\[AAcute]fica aparece en color rosa?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[TextData[{
 "Puede pasarse el cursor por encima para ver la expresi\[OAcute]n simb\
\[OAcute]lica subyacente. O bien, oprimir el ",
 Cell[BoxData["+"], "InlineCode"],
 " para que se muestren los mensajes."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:19"],

Cell["\<\
\[DownQuestion]Qu\[EAcute] c\[OAcute]digo se usa para ver c\[OAcute]mo se van \
haciendo las gr\[AAcute]ficas tipo fractal?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:20"],

Cell[TextData[{
 "Mediante un ",
 StyleBox["Gray code, ",
  FontSlant->"Italic"],
 "un ordenamiento de enteros donde solamente un d\[IAcute]gito binario cambia \
en cada paso."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notas t\[EAcute]cnicas", "TechNoteSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[TextData[{
 "Para el caso de desarrollo de software en gran escala, Wolfram Language \
cuenta con un marco operativo para la creaci\[OAcute]n y ejecuci\[OAcute]n de \
pruebas sistem\[AAcute]ticas, con funciones tales como ",
 ButtonBox["VerificationTest",
  BaseStyle->"Link"],
 " y ",
 ButtonBox["TestReport",
  BaseStyle->"Link"],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:21"],

Cell["\<\
Un objetivo prioritario en el dise\[NTilde]o \[OAcute]ptimo de un lenguaje es \
propiciar que los usuarios escriban c\[OAcute]digo de buena calidad. \
\>", "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Para explorar m\[AAcute]s", "MoreExploreSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False],

Cell[TextData[ButtonBox["Gu\[IAcute]a para depuraci\[OAcute]n en Wolfram \
Language\[NonBreakingSpace]\[RightGuillemet]",
 BaseStyle->"Link",
 ButtonData->"paclet:guide/TuningAndDebugging"]], "MoreExplore",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"Depuraci\[OAcute]n de c\[OAcute]digo: Una introducci\[OAcute]n \
elemental a Wolfram Language",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{
         "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
          "\"\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\"", 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztl01IVFEUxyctMFzUysjIyUDCTauiIJFM6ENpM4NEtJrBUaSYZMYPhCRm
rYuoICgiW0VEBVIUEbTNEMTAIqRsk6JGCVFBHx7//+4JLo/36DqvB4Ie+Mk7
7+t3733nHpzq9NlEW0ksFsuX4U8i1duQy6X6kpuRtGTzHe3ZTOuxbFemPZPb
ny7FyZ2gEqwHInICfJToguOIReywPVHHlYDzcY4hJHZ486giyBOXtfms5Pms
Bs9zUBDTow6DJOgBT8DP/+B5CepAPbgqZm+zT70Bt9VXCx6H8DwE28Gw5ufB
IT2eA1N6PKquC0V4xtUxqfkE6ARD4BHYAx5Y938Gu8GdZXq4VsNWngIfwDzY
Aa6Bm55nOKYq8NXRw29eb+Uz4JSVd4Nn4IbPs2fARUdPQcfLWAQJ8Mq6Tkdd
gGcEHHT0sHYn9Jg1dcnnnhf6vnee8xzXVkcP9wdr97eY7z0NnlrX74qpxffg
iOZ2VDp6kvqOe6AVXAb7xNQB462YNfsCfoBzoE1MzTEqHD096mgE98WsEec4
Jqamvvk8cx2kwWuw19HDXnIAbNAx03ka9IO8mO+3ScyebRZTi01i1rqguHjY
r3aJWaugOA5O6vEC+K6ebWDW0cNgv6oBnwKus87KwKDmv8BRMOBz77/6G/sV
e8lkwHWuTwm4pQ7WzGIRHgb7FXsJ9/mI5z2si42gXMw8/ByuHgb7FXsJ9yX3
IPfHFjF1xTl5v0exnrCx5gnn+fu7JC7h/z/0Y52+P+rfWX9iCXVYErg=
             "], {{0,
              34}, {26, 0}}, {0, 255}, ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {26, 34}, 
           PlotRange -> {{0, 26}, {0, 34}}], 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztXUuS47gRLX8WXtYRaJ+gl17SS+8U4/CeM+H2hDdtRY8jHF6ZR9AReATt
qrwyj6AjcO+ZaN0gLZCZwEMiQVJqSd2qwYvgdBGf/AF4+LFqfvvd37/56y+f
np5++M3pP998+88/fPz47b/+9Hx6+fOHH/72/Yf3f/njh3+8//79x99/96tT
4u9Oz79/8fT066cY9NNLSz++9uPz0+uOPv3n3Zj+40vj083npZktd5IVdJzk
hvT9pHOq78uc9I75rD/KA31n6/z03+dY1lRX64jkQh3LLpevbWI7t6N/Esv/
vdSJDpcOdpr5M74lvk/tt6VPL1VG3j7v79Qedr2XLlevoKDgsTHx8Cud+OTA
XDKM7yfOijnmlB+XC9zvuGfMm+HhqfwR8sjLY54ddbJuw05yesL7Sp2qHtY1
4+F8VjZ4Xajf2/q6Gd/HuUDH6OTvZOM21jHZmm0TsTvH/d531WZOn5o3x3lL
Ys22pnFN87Bezs6CgoLHhFsnMqd1IW1cz26TsrO8nOdSX8bgO+CwZlmHzf2L
OoXbYE08y/2e80AXcDGkbVEuzEXbIAvmA9S/kvuz+aIL5yeJHbTlVHbcQwzT
/BDncT5l6xXuLyh4k4C1Xfb8wZe9Bfcrnr0J949r43H9vV9bl2Oyn2w88Te/
Yx0+DxmiOiddiSyDk2/B/cEGFWPm/GkOeDmavo5zQ5wnaYX7CwreJvy61HGb
cc7uy63g/rEMPLEeg/tl7cxrZa/DpStZ2TOfFTo1Vy5yP88Zk02vGzkTic54
prjx/JDuFWJ501nXXCwS/Wev+9m+aN/Bdrk8dUYVZE1zv7n/4vScHQUFBY8L
f2fpz99PP1v8vob71ROV8efSruxYfj9xojujVuf92cfg/mWdPf88yDp9ed0f
8uXMZJIxroP5zN3ar6Tn6cGOsK5efd6f8S1/3n/6Nzrbirl7sj852yFuk87P
Zfzzmr1VQUHBY2M6+x/HPJnnCddY9yOXjevmkz7kqhut+xPZS9zv1/juvnvc
N3STTv5+R8XCsi+2Y+Joyy67fLijxifxXbhf5uzkeyZ/zt/yt0ADzrXs06RH
fJ7uKI7TnXfh/oKCnwvgDiD67u8W5/1JmZuc92vOndbus9wvd+D+TEq+ZQ3v
wpNTebkTMO5S4b4gZ5dp9xlnPp7/cR7F73v0g9/K4v7Ff4c17VEK9xcUvE2M
vJR828dcpc/m3wL3e05fvsPktW/0jY7n02m9PSS6FP+infHvJlyZ+4352p/h
671AWi5wv/+2R/Y5hfsLCt4icKzD2cpe3xmOZS8484nuIm/E/efqpJXfLkIc
hihdvtnP7YvcuYq/Ww1nM7EM/v5I2y5zzCV3vXJeF/YCg7Yx8kv2LMj9MofI
7/YV7i8oeJOY1vhwxh+e5JvPS+5643vGG3H/mTr9efYi9/vf5+qUHebc6O0P
c4M8e+Mc3rzLDWcvF3C/P6fnuSdno5xX+d/Lm7mnKNxfUPDmodeeBZdjXD+P
sYw5v6CgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoOBr
BxE9n57aPV/aloLr4dSeFbdr9m/CXlmf60fVPXTdGi5mHLvqS9uyhNz45fTm
9LTu3y9jXcFacHu1/NRXktlmnprzXb8ZcQ19Pxdw3K7WTtcG2+bQ30nf4fQc
7zXX3BIuZhy79kryKhl3Kt1K23J6tVK2OX7Bh69mbFv+FkzgeVpg/r9bL5CZ
Q8v5D8n99+S1jP4W43hm3Zvbfivuz/nN6Y7/b/57dCcdwzX6K/T9VqXfgvuj
MYZpBPPluWPRGr9KdkdfyXz8iDxzLzi+5/Ac+d/PHkfQB7bcT+SpOP/huJ+m
PflDcj/Eu7+NZV7PXbn/nrhWf70X97NMGdM1v+M6b8tp0q+T/+/cCh/ISrsG
h1wLj8Yz9wJN5z3C+x3/3KgyY7/g8XeE8vn/z1dAncnP7Rk3xOsrRof9SHiF
6x/gXc4Zxb6dkvuO4v1oT/G6R/JQhvt3w/mNsmuUAbL3Kk/rF50tlNnyv3tV
VvQk8SWDA0HeJba3UFfi2UIbYb2Dtol9HyBf4thr+1a0/Vbpk3bdUYoWZRP0
M8Nu3dai38ntVLmEs9jHAylAvu6zkT4lC9tI+yKx2yt5jZJh6TO5FmQKz6O/
e7DJv4PPOF6cPh1jHweK+4H2S2yUdnT+yzkz1hkobifpmxsK3HNkeysKYy6q
Z8TA25nJrykdv63hK/ogequZmCFqMtZfZI9nHIsSr0bZvKW0H3nZNMW3W5Cx
4bwOftZcRErG0SqXqROt+4146jEkcPZIv+gytmC/ORpp77hOBfk9hfY5gFxs
syPIGYz2OHL5HeftVLqgUXajjcJrggr6j9drxHWO+0XHEWUs2N5COnG5DduB
aVhfbMW4DqT4SNu30PYt1JUz/IEC9+vYNcr3WsVvzu6aYuA4S//+Xcr9PYUx
Vis5EoOR3wxZDZTRvmjewHg+G/51YFevdam4SnsPYOfR6lOUtiv6LmPK4n4d
I91G6HMFaRi33rBdxwPXN6u5aCa/A3nYBtKndH/BdulADtoXjQUK9/g5H1tD
jo59ZdiD+a68tDPOix3EqTb8dn0SuUivtYntdGU8Ry/FWwPyrfEvfjT8/sw2
Hw25so4R3h0otNWg5EgZbCdp43fqfc96fd80bPZtB3Zu4F307SBN0Km6En/x
p9V1Vfk57u8usB25H9dcYheuBSVGnRH7Z1Wvh3o5WzBN+qbEYfTD0O39Vr7X
/C593rJbxoXo92sh8MXkEMtmpa+DNOl/yTyiYq59ETt7CuM8GrOgbwv1RJ81
12xQptgKunCtKjokFr3hp+wVrDbMxUig98IbitcRWp7E6cD5yE/S18W/41MG
lk0q38nG8St9uNV+UeifjREjgV47VUoO1rHGs6uLY1F4sTbigvviDuo74LgU
e5GTxL4NxecoTS52ZLRTLt4cx1YeyLf6jqCH52iVMWKH8Yx4At4PIFfGS63K
1DO6TP6E2O4hntomwbOqJzIP/C7xrzJxneP+s22nzFwDduCYiPq7jrOSl/hu
2ELWe8bvtdwv7Tpn99wYjOKTszmnf6WsJe5vjTTxD/di0RhBG6C+jFVXRniy
ARsaUnMH6MT5Rfw/qvfV3J+xbUfqPG0uTpSO2zV9Zzafy1jjt13ha2/YJnEU
v/ReCetYPjo+30I7aHsiHieY3/l9y++yj+lJ7Q8pPmPRwHVTEjsrzcqnM877
oU6vn5xeupz75dHr/npGV44/8cynA1lZu1V935/Fzpm43or7W5U+GDJ1H/sa
ud/a22q7H5n7BVZfrjL6JCbST/H8we/dDJ1Nzn8rHksxUmm4Lu4hJkvcr+Px
2dxP8ZnPTrfDgq89pAknu7EjXHtYqBP5SBPvH0BOS2EsYhwkrYc4bpRM5H55
RE8H9Vt+pC9k19or4ymoM/lWPMWfjVXH0kvruL/D94zcc7jf2WmdidUzNmXj
BeWlzc2zAlW2hbQk1mfYvsRDuEeMzkUgrp1RJvGdwt5X1iXCI7iX9z5k7OlU
uo69xZ9ipz6vQBuX+BrP2a39eGPo6zKyTF0Z2zXXJby8BKjjoM9PPf/O2a9t
ps/n/tbQoeXdnPspvneQ9brm47Xc731iO7cUjzWpg/OBnKVpXdhOms/ceHHj
WOb/PcVj34/1mZhIu+tvNyIOtmK3Nt6kznwonK/WUEbSJHbjOSyFfdhGyzXi
jW2gY4W6XPmN2GXUqWd04fjvKb3LOpD6bmRNvCjufw7VTFw/l/u17Tnuxz1h
C+W8Hoq/F9zN+C79aU9qH2vE/8i6OoL7UiXb6ZL92pxNObvP5n6ly/nTqnrO
1i3F34HUGTlbKOPHLa3jfvFP4iRjpJmxG2Ng3YNondhXdhS+sSEK/QbHQqPr
WXGbsWlHcDdqlJmLx2rup5iHWq6LY8/Jxn7W5nSQ3YfEhx2F71twnYAxi3y2
dFE6XqSM9IGBfxZdlWGLq79hfXKXKWN7MGIl/nczbZekZeKtgbGaW3MIjmTw
HLwvcr+KF8IaB/Wcj6S+veI0HO/OXpnL+zlZSq7Umf3Gmi7k/hnbTe43/CKr
HKXfkUkc0fdWyfD9GcrgXhfL1Zxfq7x2xnfLbuvs2rLRp62IR2XEQNDMyHG+
JvdCtIL7M3aMZxUz+qJ5PCNno+pY40XfCUXjl87jfjzzIYI7OChzbe7XaJVM
iWVuLb523a8x3skauhyk76CPOA4GsvsFzhsI/J0NXebA6RWpeQnkRnn8c63K
JGlWvvHgPOj0bLUNbJ9LT85+tF7LD8r8XRQu2/Cj71yljt6jJT7SNJYaZccG
5Ro2ZeNFExdI+2bPe5S/FaTVa2ynMOd72y15hj6JWa6MtJfpO5RpQW8utjWX
S3RBf9lQ/O1E5PuS3RT+Fo3ui+Z4UHU3FL5bxnhLDLJxMmwQ+2ScJf3W6pfK
v+z5qOGvtrmy0g0dpk96/KIeVS7X1lK/Ql8N+7LxyOm09BsPyh3HhZJZqXe0
zepDbgwPFP4+hoxpUnWlD1VaF8j2bavjQGHe6Sic0yfraCi7pRV9suC+4H4g
87w/4ygoKHgcUNhb4f2YnMsTLawpztTVa5kUzhH7a+kpuC0o3vc2X9qegoKC
80Hp78Phmr+7si48q5O9hqwdrzbHFNwWFL61rr60LQUFBZeDwt9N7Sl8O1nf
SFdD4XuijtQ3RXP4P6lulfg=
             "], {{0, 34}, {383, 0}}, {0, 255}, 
             ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {383, 34}, 
           PlotRange -> {{0, 383}, {0, 34}}]}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {174, 47}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL2-46-writing-good-code.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL2-46-writing-good-code.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> RGBColor[0.835294, 0.364706, 0.0196078],
                   Evaluator -> Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], 
              "\"C\[OAcute]mo escribir c\[OAcute]digo de buena calidad\"", 
              TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, 
              "C\[OAcute]mo escribir c\[OAcute]digo de buena calidad", 
              "Tooltip"]& ], 
            TemplateBox[{5}, "Spacer1"], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL2-what-we-havent-discussed.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL2-what-we-havent-discussed.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  RGBColor[0.835294, 0.364706, 0.0196078], Evaluator -> 
                  Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Lo que no se vio en el libro\"", 
              TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Lo que no se vio en el libro", "Tooltip"]& ]}, 
           "RowWithSeparators"], Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.835294, 0.364706, 0.0196078], ImageSize -> {35, 30}, 
             Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.952941, 0.509804, 0], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Prefacio" :> 
          NotebookLocate[{"EIWL2-0a-preface.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[DownQuestion]Qu\[EAcute] es Wolfram Language?" :> 
          NotebookLocate[{"EIWL2-0b-what-is-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Aspectos pr\[AAcute]cticos en el uso de Wolfram Language" :> 
          NotebookLocate[{
            "EIWL2-0c-practicalities-of-using-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Otros recursos" :> 
          NotebookLocate[{"EIWL2-0d-other-resources.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Sobre la traducci\[OAcute]n al espa\[NTilde]ol" :> 
          NotebookLocate[{"EIWL2-0e-translation-notes.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]1\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Inicio: aritm\[EAcute]tica elemental" :> 
          NotebookLocate[{
            "EIWL2-01-starting-out-elementary-arithmetic.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Introducci\[OAcute]n a las funciones" :> 
          NotebookLocate[{"EIWL2-02-introducing-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Un primer vistazo a las listas" :> 
          NotebookLocate[{"EIWL2-03-first-look-at-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Visualizaci\[OAcute]n de listas" :> 
          NotebookLocate[{"EIWL2-04-displaying-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Operaciones con listas" :> 
          NotebookLocate[{"EIWL2-05-operations-on-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Construcci\[OAcute]n de tablas" :> 
          NotebookLocate[{"EIWL2-06-making-tables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Colores y estilos" :> 
          NotebookLocate[{"EIWL2-07-colors-and-styles.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Objetos gr\[AAcute]ficos elementales" :> 
          NotebookLocate[{"EIWL2-08-basic-graphics-objects.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Manipulaci\[OAcute]n interactiva" :> 
          NotebookLocate[{"EIWL2-09-interactive-manipulation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Im\[AAcute]\
genes" :> NotebookLocate[{"EIWL2-10-images.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Cadenas de \
caracteres y texto" :> 
          NotebookLocate[{"EIWL2-11-strings-and-text.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Sonido" :> 
          NotebookLocate[{"EIWL2-12-sound.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "13\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Arreglos o \
listas de listas" :> 
          NotebookLocate[{"EIWL2-13-arrays-or-lists-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Coordenadas \
y gr\[AAcute]ficos" :> 
          NotebookLocate[{"EIWL2-14-coordinates-and-graphics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]El alcance \
de Wolfram Language" :> 
          NotebookLocate[{
            "EIWL2-15-the-scope-of-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Datos del \
mundo real" :> 
          NotebookLocate[{"EIWL2-16-real-world-data.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "17\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Unidades" :> 
          NotebookLocate[{"EIWL2-17-units.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Geocomputaci\[OAcute]n" :> 
          NotebookLocate[{"EIWL2-18-geocomputation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Fechas y \
horas" :> NotebookLocate[{"EIWL2-19-dates-and-times.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Opciones" :> 
          NotebookLocate[{"EIWL2-20-options.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "21\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Grafos y \
redes" :> NotebookLocate[{"EIWL2-21-graphs-and-networks.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "22\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Aprendizaje \
autom\[AAcute]tico" :> 
          NotebookLocate[{"EIWL2-22-machine-learning.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "23\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]M\[AAcute]s \
sobre n\[UAcute]meros" :> 
          NotebookLocate[{"EIWL2-23-more-about-numbers.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "24\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]M\[AAcute]s \
formas de visualizaci\[OAcute]n" :> 
          NotebookLocate[{"EIWL2-24-more-forms-of-visualization.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "25\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Maneras de \
aplicar funciones" :> 
          NotebookLocate[{"EIWL2-25-ways-to-apply-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "26\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Funciones \
puras an\[OAcute]nimas" :> 
          NotebookLocate[{"EIWL2-26-pure-anonymous-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "27\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Aplicaci\
\[OAcute]n repetida de funciones " :> 
          NotebookLocate[{"EIWL2-27-applying-functions-repeatedly.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "28\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Pruebas y \
condicionales" :> 
          NotebookLocate[{"EIWL2-28-tests-and-conditionals.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "29\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]M\[AAcute]s \
sobre las funciones puras" :> 
          NotebookLocate[{"EIWL2-29-more-about-pure-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "30\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Reorganizaci\[OAcute]n de listas" :> 
          NotebookLocate[{"EIWL2-30-rearranging-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "31\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Partes de \
listas" :> NotebookLocate[{"EIWL2-31-parts-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "32\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Patrones" :> 
          NotebookLocate[{"EIWL2-32-patterns.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "33\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Expresiones \
y su estructura" :> 
          NotebookLocate[{"EIWL2-33-expressions-and-their-structure.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "34\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Asociaciones" :> 
          NotebookLocate[{"EIWL2-34-associations.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "35\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Comprensi\
\[OAcute]n del lenguaje natural" :> 
          NotebookLocate[{"EIWL2-35-natural-language-understanding.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "36\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Construcci\
\[OAcute]n de sitios web y aplicaciones" :> 
          NotebookLocate[{"EIWL2-36-creating-websites-and-apps.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "37\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Composici\
\[OAcute]n y visualizaci\[OAcute]n" :> 
          NotebookLocate[{"EIWL2-37-layout-and-display.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "38\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Asignaci\
\[OAcute]n de nombres a cosas" :> 
          NotebookLocate[{"EIWL2-38-assigning-names-to-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "39\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Valores \
inmediatos y diferidos" :> 
          NotebookLocate[{"EIWL2-39-immediate-and-delayed-values.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "40\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Funciones \
definidas por el usuario" :> 
          NotebookLocate[{"EIWL2-40-defining-your-own-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "41\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]M\[AAcute]s \
informaci\[OAcute]n sobre los patrones" :> 
          NotebookLocate[{"EIWL2-41-more-about-patterns.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "42\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Cadenas de \
caracteres y plantillas " :> 
          NotebookLocate[{"EIWL2-42-string-patterns-and-templates.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "43\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]C\[OAcute]\
mo guardar cosas" :> 
          NotebookLocate[{"EIWL2-43-storing-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "44\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Importar y \
exportar" :> 
          NotebookLocate[{"EIWL2-44-importing-and-exporting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "45\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Conjuntos \
de datos" :> 
          NotebookLocate[{"EIWL2-45-datasets.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "46\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]C\[OAcute]\
mo escribir c\[OAcute]digo de buena calidad" :> 
          NotebookLocate[{"EIWL2-46-writing-good-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "47\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Depuraci\
\[OAcute]n de c\[OAcute]digo" :> 
          NotebookLocate[{"EIWL2-47-debugging-your-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Lo que no se vio en el libro" :> 
          NotebookLocate[{"EIWL2-what-we-havent-discussed.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Ep\[IAcute]logo: ser un programador" :> 
          NotebookLocate[{"EIWL2-being-a-programmer.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Respuestas a los ejercicios" :> 
          NotebookLocate[{"EIWL2-answers-to-exercises.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "\[CapitalIAcute]ndice" :> 
          NotebookLocate[{"EIWL2-book-index.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> 
   RGBColor[0.835294, 0.364706, 0.0196078], CellMargins -> {{0, 0}, {0, -1}}, 
   CellFrameMargins -> {{27, 0}, {1, 7}}, Background -> 
   RGBColor[0.952941, 0.509804, 0], CellTags -> "DockedCellLogoCell"], 
  Cell["SEGUNDA EDICI\[CapitalOAcute]N", "Text", FontFamily -> 
   "Source Sans Pro", CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> False,
    CellMargins -> {{0, 0}, {-1, -1}}, CellFrameMargins -> {{66, 0}, {2, 4}}, 
   CellFrameColor -> RGBColor[0.952941, 0.509804, 0], FontSize -> 10, 
   FontTracking -> "Extended", FontColor -> RGBColor[1, 0.929412, 0.721569], 
   Background -> RGBColor[0.862745, 0.309804, 0], CellTags -> 
   "DockedCellLogoCell"]},
PrintingStartingPageNumber->381,
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    An Elementary Introduction to the Wolfram Language", "Header"]}], 
    "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None,
    None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox[" | Debugging Your Code \[LongDash] wolfr.am/eiwl-", "Header"], 
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowAutoSpellCheck->False,
ShowPredictiveInterface->False,
ShowSyntaxStyles->False,
AutoStyleOptions->{"HighlightMisspelledWords"->False},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 12}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], MenuSortingValue -> 10010, 
          MenuCommandKey -> "1", FontFamily -> "Source Sans Pro", FontSize -> 
          16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, 2018)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p:291"->{
  Cell[672, 24, 325, 9, 70, "SectionDoubleDigit",ExpressionUUID->"724ea0fb-f56a-48d9-8ad8-8d6ad529682c",
   CounterAssignments->{{"Section", 46}, {"Subsection", 0}, {"Subsubsection", 0}, {"Exercise", 0}},
   CellTags->"p:291"]},
 "i:1"->{
  Cell[1000, 35, 461, 10, 70, "Text",ExpressionUUID->"0bb57e6b-f640-4227-b1af-290061f8ff49",
   CellTags->"i:1"]},
 "i:2"->{
  Cell[1464, 47, 673, 13, 70, "Text",ExpressionUUID->"6b0ab68a-8ea2-4e71-9502-920eddca29e1",
   CellTags->"i:2"]},
 "i:3"->{
  Cell[2433, 71, 203, 7, 70, "CodeCaption",ExpressionUUID->"56eb16e8-8e25-4b8d-a8e9-7f3298883e91",
   CellTags->"i:3"]},
 "i:4"->{
  Cell[3147, 97, 440, 10, 70, "Text",ExpressionUUID->"785e6446-b761-45b4-9b1a-d62cab159818",
   CellTags->"i:4"]},
 "i:5"->{
  Cell[3590, 109, 358, 15, 70, "CodeCaption",ExpressionUUID->"1901439d-81da-457b-b04d-c1f4d8c623d5",
   CellTags->"i:5"]},
 "i:6"->{
  Cell[4656, 155, 412, 10, 70, "Text",ExpressionUUID->"214a128c-5e20-4b4a-906b-be4c5ab2b960",
   CellTags->"i:6"]},
 "i:7"->{
  Cell[5794, 199, 245, 7, 70, "CodeCaption",ExpressionUUID->"e9bd31ff-a441-471a-a651-de5d28fff58e",
   CellTags->"i:7"]},
 "LastCellOfAPage"->{
  Cell[6636, 232, 533, 14, 70, "Text",ExpressionUUID->"9a7261a3-799d-42a9-8b73-b7854be840be",
   CellTags->{"LastCellOfAPage", "i:8"}],
  Cell[19363, 651, 202, 7, 70, "Output",ExpressionUUID->"6dde8594-bef5-4334-a3a2-c4f238fd8171",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[69619, 1807, 1735, 64, 70, "Exercise",ExpressionUUID->"a765b395-2074-4865-b44e-58bed33b4c87",
   CellTags->"LastCellOfAPage"],
  Cell[77946, 2095, 298, 7, 70, "MoreExplore",ExpressionUUID->"65e33449-9f22-44ef-a469-e3684c2c5227",
   CellTags->"LastCellOfAPage"]},
 "i:8"->{
  Cell[6636, 232, 533, 14, 70, "Text",ExpressionUUID->"9a7261a3-799d-42a9-8b73-b7854be840be",
   CellTags->{"LastCellOfAPage", "i:8"}]},
 "p:292"->{
  Cell[7172, 248, 376, 15, 70, "CodeCaption",ExpressionUUID->"fc2a9f6e-93f0-4975-87e4-1091a6c27c2d",
   CellTags->{"p:292", "i:9"}]},
 "i:9"->{
  Cell[7172, 248, 376, 15, 70, "CodeCaption",ExpressionUUID->"fc2a9f6e-93f0-4975-87e4-1091a6c27c2d",
   CellTags->{"p:292", "i:9"}]},
 "i:10"->{
  Cell[8368, 296, 544, 11, 70, "Text",ExpressionUUID->"f0cd6401-62fd-4341-b4f8-f6c3db3fe1e9",
   CellTags->"i:10"]},
 "i:11"->{
  Cell[18771, 620, 214, 8, 70, "CodeCaption",ExpressionUUID->"773f84a7-df3c-437b-ade5-a3036c8863c0",
   CellTags->"i:11"]},
 "p:293"->{
  Cell[19580, 661, 281, 10, 70, "Text",ExpressionUUID->"97d2d783-0f14-4a6a-839e-5d67b4ce6b95",
   CellTags->{"p:293", "i:12"}]},
 "i:12"->{
  Cell[19580, 661, 281, 10, 70, "Text",ExpressionUUID->"97d2d783-0f14-4a6a-839e-5d67b4ce6b95",
   CellTags->{"p:293", "i:12"}]},
 "i:13"->{
  Cell[19864, 673, 246, 8, 70, "CodeCaption",ExpressionUUID->"f13bdd65-c1db-4b36-b6af-acc108e31a3a",
   CellTags->"i:13"]},
 "i:14"->{
  Cell[25743, 798, 426, 18, 70, "Text",ExpressionUUID->"39696791-38c8-4c2b-95ec-bdbc7694713a",
   CellTags->"i:14"]},
 "p:294"->{
  Cell[72824, 1919, 125, 4, 70, "QASection",ExpressionUUID->"8b034ea2-d913-4163-93ab-74a98caf3045",
   CellTags->"p:294"]},
 "i:15"->{
  Cell[73164, 1933, 665, 17, 70, "Answer",ExpressionUUID->"ee73f9ea-60fd-4f96-b479-152985758630",
   CellTags->"i:15"]},
 "i:16"->{
  Cell[74035, 1960, 689, 15, 70, "Answer",ExpressionUUID->"cfa7194d-240d-42f1-b905-8aec28416296",
   CellTags->"i:16"]},
 "i:17"->{
  Cell[74928, 1985, 466, 10, 70, "Answer",ExpressionUUID->"553bb259-64d2-439d-9aa0-9904ae333127",
   CellTags->"i:17"]},
 "i:18"->{
  Cell[75586, 2005, 360, 9, 70, "Answer",ExpressionUUID->"41387758-850a-4099-8888-66adad14cf40",
   CellTags->"i:18"]},
 "i:19"->{
  Cell[76162, 2024, 305, 9, 70, "Answer",ExpressionUUID->"f885e39e-6229-4698-bcea-77f44f1ac12d",
   CellTags->"i:19"]},
 "i:20"->{
  Cell[76470, 2035, 232, 7, 70, "Question",ExpressionUUID->"d4f9b4ab-a6fb-40fd-bd33-ed1b1b4a2992",
   CellTags->"i:20"]},
 "i:21"->{
  Cell[77108, 2063, 439, 14, 70, "TechNote",ExpressionUUID->"e16a2329-4af8-4438-b5e7-6e46c3d82c1f",
   CellTags->"i:21"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p:291", 169524, 3945},
 {"i:1", 169763, 3949},
 {"i:2", 169888, 3952},
 {"i:3", 170013, 3955},
 {"i:4", 170144, 3958},
 {"i:5", 170269, 3961},
 {"i:6", 170402, 3964},
 {"i:7", 170528, 3967},
 {"LastCellOfAPage", 170672, 3970},
 {"i:8", 171240, 3980},
 {"p:292", 171389, 3983},
 {"i:9", 171533, 3986},
 {"i:10", 171678, 3989},
 {"i:11", 171806, 3992},
 {"p:293", 171942, 3995},
 {"i:12", 172082, 3998},
 {"i:13", 172222, 4001},
 {"i:14", 172357, 4004},
 {"p:294", 172487, 4007},
 {"i:15", 172622, 4010},
 {"i:16", 172754, 4013},
 {"i:17", 172886, 4016},
 {"i:18", 173018, 4019},
 {"i:19", 173149, 4022},
 {"i:20", 173280, 4025},
 {"i:21", 173413, 4028}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[672, 24, 325, 9, 70, "SectionDoubleDigit",ExpressionUUID->"724ea0fb-f56a-48d9-8ad8-8d6ad529682c",
 CounterAssignments->{{"Section", 46}, {"Subsection", 0}, {"Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:291"],
Cell[1000, 35, 461, 10, 70, "Text",ExpressionUUID->"0bb57e6b-f640-4227-b1af-290061f8ff49",
 CellTags->"i:1"],
Cell[1464, 47, 673, 13, 70, "Text",ExpressionUUID->"6b0ab68a-8ea2-4e71-9502-920eddca29e1",
 CellTags->"i:2"],
Cell[2140, 62, 290, 7, 70, "Text",ExpressionUUID->"fb106467-1623-4a79-823f-88ba0d51e340"],
Cell[2433, 71, 203, 7, 70, "CodeCaption",ExpressionUUID->"56eb16e8-8e25-4b8d-a8e9-7f3298883e91",
 CellTags->"i:3"],
Cell[2639, 80, 505, 15, 70, "Input",ExpressionUUID->"4b83fe89-8648-4aa2-a8f0-93a7fdcb2825"],
Cell[3147, 97, 440, 10, 70, "Text",ExpressionUUID->"785e6446-b761-45b4-9b1a-d62cab159818",
 CellTags->"i:4"],
Cell[3590, 109, 358, 15, 70, "CodeCaption",ExpressionUUID->"1901439d-81da-457b-b04d-c1f4d8c623d5",
 CellTags->"i:5"],
Cell[CellGroupData[{
Cell[3973, 128, 232, 8, 70, "Input",ExpressionUUID->"061426f2-4c06-4a0b-8796-9a768b608165"],
Cell[4208, 138, 264, 6, 70, "Message",ExpressionUUID->"49b6b2ca-2c3b-4e42-b917-8d8c9f824b6a"],
Cell[4475, 146, 166, 6, 70, "Output",ExpressionUUID->"8589f4c0-27c8-4918-ba90-16cab4631ad8",
 Evaluatable->False]
}, Open  ]],
Cell[4656, 155, 412, 10, 70, "Text",ExpressionUUID->"214a128c-5e20-4b4a-906b-be4c5ab2b960",
 CellTags->"i:6"],
Cell[5071, 167, 318, 11, 70, "CodeCaption",ExpressionUUID->"8bfd3338-019e-4db0-9352-47c47e4b55be"],
Cell[CellGroupData[{
Cell[5414, 182, 157, 5, 70, "Input",ExpressionUUID->"2fa969fa-4dcc-4d7b-b2ab-3e4afb275312"],
Cell[5574, 189, 205, 7, 70, "Output",ExpressionUUID->"48e1a403-ae1b-44f3-9a83-12fc404501e1",
 Evaluatable->False]
}, Open  ]],
Cell[5794, 199, 245, 7, 70, "CodeCaption",ExpressionUUID->"e9bd31ff-a441-471a-a651-de5d28fff58e",
 CellTags->"i:7"],
Cell[CellGroupData[{
Cell[6064, 210, 324, 11, 70, "Input",ExpressionUUID->"004bd033-c3da-4de4-8db3-0687815c951f"],
Cell[6391, 223, 230, 6, 70, "Output",ExpressionUUID->"c6efc37f-e6ae-4c6b-89a0-1a76b9cf28d6",
 Evaluatable->False]
}, Open  ]],
Cell[6636, 232, 533, 14, 70, "Text",ExpressionUUID->"9a7261a3-799d-42a9-8b73-b7854be840be",
 CellTags->{"LastCellOfAPage", "i:8"}],
Cell[7172, 248, 376, 15, 70, "CodeCaption",ExpressionUUID->"fc2a9f6e-93f0-4975-87e4-1091a6c27c2d",
 CellTags->{"p:292", "i:9"}],
Cell[CellGroupData[{
Cell[7573, 267, 458, 15, 70, "Input",ExpressionUUID->"50ef596f-612d-4dab-8a7a-614fd27f3488"],
Cell[8034, 284, 319, 9, 70, "Output",ExpressionUUID->"03c893e4-d5e7-49a5-bd8a-d5b1bacc24f4",
 Evaluatable->False]
}, Open  ]],
Cell[8368, 296, 544, 11, 70, "Text",ExpressionUUID->"f0cd6401-62fd-4341-b4f8-f6c3db3fe1e9",
 CellTags->"i:10"],
Cell[8915, 309, 185, 6, 70, "CodeCaption",ExpressionUUID->"157643d4-bb6d-4f23-be8b-91de2e0f5973"],
Cell[CellGroupData[{
Cell[9125, 319, 506, 16, 70, "Input",ExpressionUUID->"85bf46f1-4a7f-4e3d-ab15-85137065e963"],
Cell[9634, 337, 6140, 169, 70, "Output",ExpressionUUID->"398b8711-0652-4154-b39e-5d7ab5dfa97b",
 Evaluatable->False]
}, Open  ]],
Cell[15789, 509, 414, 15, 70, "CodeCaption",ExpressionUUID->"6a2a7d70-9372-4198-80b6-1f46946400ae"],
Cell[CellGroupData[{
Cell[16228, 528, 501, 16, 70, "Input",ExpressionUUID->"ca227c75-20d3-4f14-9eb4-e0c4fd45432e"],
Cell[16732, 546, 319, 9, 70, "Output",ExpressionUUID->"76d6f80f-85d9-46ba-8e22-9cd444940fd7",
 Evaluatable->False]
}, Open  ]],
Cell[17066, 558, 275, 11, 70, "CodeCaption",ExpressionUUID->"af876315-cd11-4107-94ef-72bf3571418c"],
Cell[CellGroupData[{
Cell[17366, 573, 657, 21, 70, "Input",ExpressionUUID->"c6366b52-2a75-4eaa-8f2b-ea4ac725203e"],
Cell[18026, 596, 279, 8, 70, "Output",ExpressionUUID->"0d71b13f-4e33-4d6a-a158-9bfe972e1097",
 Evaluatable->False]
}, Open  ]],
Cell[18320, 607, 448, 11, 70, "Text",ExpressionUUID->"1851a5ec-31d8-4d9e-946a-b61dfaa7ff3f"],
Cell[18771, 620, 214, 8, 70, "CodeCaption",ExpressionUUID->"773f84a7-df3c-437b-ade5-a3036c8863c0",
 CellTags->"i:11"],
Cell[CellGroupData[{
Cell[19010, 632, 229, 8, 70, "Input",ExpressionUUID->"810853bf-a0cf-43e7-94c0-8a5aa65eb2e9"],
Cell[CellGroupData[{
Cell[19264, 644, 26, 0, 70, "Echo",ExpressionUUID->"a8d5d68c-9428-4721-92c1-473d39211f19"],
Cell[19293, 646, 26, 0, 70, "Echo",ExpressionUUID->"d6c59fd4-eb6a-475d-a508-ff611819e74d"],
Cell[19322, 648, 26, 0, 70, "Echo",ExpressionUUID->"29c8d39f-5706-49a4-8eb8-166f552bebb3"]
}, Open  ]],
Cell[19363, 651, 202, 7, 70, "Output",ExpressionUUID->"6dde8594-bef5-4334-a3a2-c4f238fd8171",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[19580, 661, 281, 10, 70, "Text",ExpressionUUID->"97d2d783-0f14-4a6a-839e-5d67b4ce6b95",
 CellTags->{"p:293", "i:12"}],
Cell[19864, 673, 246, 8, 70, "CodeCaption",ExpressionUUID->"f13bdd65-c1db-4b36-b6af-acc108e31a3a",
 CellTags->"i:13"],
Cell[CellGroupData[{
Cell[20135, 685, 391, 13, 70, "Input",ExpressionUUID->"b7b43107-8189-4fc0-a60b-87d5c52e41b2"],
Cell[20529, 700, 4837, 84, 70, "PrintTemporary",ExpressionUUID->"2d84a35e-0653-484c-82b0-8fe69d731976"],
Cell[25369, 786, 359, 9, 70, "Output",ExpressionUUID->"fc0fc76f-4a06-4c26-b3df-5b6f3b22c76d",
 Evaluatable->False]
}, Open  ]],
Cell[25743, 798, 426, 18, 70, "Text",ExpressionUUID->"39696791-38c8-4c2b-95ec-bdbc7694713a",
 CellTags->"i:14"],
Cell[26172, 818, 269, 11, 70, "CodeCaption",ExpressionUUID->"5371d1e8-c1a1-485a-9ab5-d238239bcddf"],
Cell[CellGroupData[{
Cell[26466, 833, 276, 9, 70, "Input",ExpressionUUID->"f118df95-e11d-472d-96d4-0b01e8d9bc31"],
Cell[26745, 844, 272, 10, 70, "Output",ExpressionUUID->"2b756a1e-dca9-4112-926c-3bf6fc7adbe3",
 Evaluatable->False]
}, Open  ]],
Cell[27032, 857, 341, 13, 70, "CodeCaption",ExpressionUUID->"0e8a63e7-5386-400a-8c02-289aa283be18"],
Cell[CellGroupData[{
Cell[27398, 874, 457, 14, 70, "Input",ExpressionUUID->"142bbe9e-8287-4f56-b1eb-80dc9faf346a"],
Cell[27858, 890, 285, 9, 70, "Output",ExpressionUUID->"30129878-9275-433b-9de5-83b24977ff19",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28192, 905, 102, 3, 70, "VocabularySection",ExpressionUUID->"9067aac4-3398-4c61-b402-2d9e57fae393"],
Cell[28297, 910, 2138, 70, 70, "VocabularyTable",ExpressionUUID->"b3d10280-4723-410c-9aad-0e4d4e19bcb7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30472, 985, 1722, 45, 70, "ExerciseSection",ExpressionUUID->"e585f7bd-0f60-48c2-85ac-cc2ab5e42506"],
Cell[CellGroupData[{
Cell[32219, 1034, 1192, 37, 70, "ExerciseSummaryCell",ExpressionUUID->"5396ca5a-5fc1-4c88-b2ff-7bba7a83b4ef"],
Cell[CellGroupData[{
Cell[33436, 1075, 1235, 41, 70, "Exercise",ExpressionUUID->"4de82444-da2c-4b24-a7fd-746a70f69351"],
Cell[34674, 1118, 32329, 590, 70, "ExerciseOutput",ExpressionUUID->"263a52a1-05d2-4489-a090-3b4f930c80e5"]
}, Closed]],
Cell[CellGroupData[{
Cell[67040, 1713, 1414, 53, 70, "Exercise",ExpressionUUID->"1ce530f6-6fba-444e-bfc0-284abb5f8fe4"],
Cell[68457, 1768, 1125, 34, 70, "ExerciseOutput",ExpressionUUID->"0290c572-6615-4a38-a58e-d620b88107c2"]
}, Closed]],
Cell[CellGroupData[{
Cell[69619, 1807, 1735, 64, 70, "Exercise",ExpressionUUID->"a765b395-2074-4865-b44e-58bed33b4c87",
 CellTags->"LastCellOfAPage"],
Cell[71357, 1873, 1406, 39, 70, "ExerciseOutput",ExpressionUUID->"e37254e5-8a42-43ff-9608-960dcdb3f9e6"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[72824, 1919, 125, 4, 70, "QASection",ExpressionUUID->"8b034ea2-d913-4163-93ab-74a98caf3045",
 CellTags->"p:294"],
Cell[72952, 1925, 209, 6, 70, "Question",ExpressionUUID->"2c7fa709-b648-4f45-ac17-9cf77c86d1a3"],
Cell[73164, 1933, 665, 17, 70, "Answer",ExpressionUUID->"ee73f9ea-60fd-4f96-b479-152985758630",
 CellTags->"i:15"],
Cell[73832, 1952, 200, 6, 70, "Question",ExpressionUUID->"3e44b70c-cd55-46eb-95c7-962b1b5eb170"],
Cell[74035, 1960, 689, 15, 70, "Answer",ExpressionUUID->"cfa7194d-240d-42f1-b905-8aec28416296",
 CellTags->"i:16"],
Cell[74727, 1977, 198, 6, 70, "Question",ExpressionUUID->"6719a51f-5c6c-4926-82b8-0ebba1525c42"],
Cell[74928, 1985, 466, 10, 70, "Answer",ExpressionUUID->"553bb259-64d2-439d-9aa0-9904ae333127",
 CellTags->"i:17"],
Cell[75397, 1997, 186, 6, 70, "Question",ExpressionUUID->"02ada469-755b-4106-a48c-b5505cddeccd"],
Cell[75586, 2005, 360, 9, 70, "Answer",ExpressionUUID->"41387758-850a-4099-8888-66adad14cf40",
 CellTags->"i:18"],
Cell[75949, 2016, 210, 6, 70, "Question",ExpressionUUID->"832214d0-84df-4559-be56-6f3923191e4c"],
Cell[76162, 2024, 305, 9, 70, "Answer",ExpressionUUID->"f885e39e-6229-4698-bcea-77f44f1ac12d",
 CellTags->"i:19"],
Cell[76470, 2035, 232, 7, 70, "Question",ExpressionUUID->"d4f9b4ab-a6fb-40fd-bd33-ed1b1b4a2992",
 CellTags->"i:20"],
Cell[76705, 2044, 252, 9, 70, "Answer",ExpressionUUID->"830d6c70-45f8-44ba-aa3e-19688667b974"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76994, 2058, 111, 3, 70, "TechNoteSection",ExpressionUUID->"476505aa-a703-442e-bcf8-93f2ca18335c"],
Cell[77108, 2063, 439, 14, 70, "TechNote",ExpressionUUID->"e16a2329-4af8-4438-b5e7-6e46c3d82c1f",
 CellTags->"i:21"],
Cell[77550, 2079, 239, 6, 70, "TechNote",ExpressionUUID->"fb46a649-c9c4-41f9-8a9b-2d2f3b692259"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77826, 2090, 117, 3, 70, "MoreExploreSection",ExpressionUUID->"87be989d-fb97-4701-a449-7a429e0599a4"],
Cell[77946, 2095, 298, 7, 70, "MoreExplore",ExpressionUUID->"65e33449-9f22-44ef-a469-e3684c2c5227",
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature jQcSWzglBiK4YjY8PP4RnYau *)
